pub struct BulkWritableCableRequest {Show 14 fields
pub id: Uuid,
pub termination_a_type: String,
pub termination_b_type: String,
pub length_unit: Option<LengthUnitEnum>,
pub type: Option<CableTypeChoices>,
pub termination_a_id: Uuid,
pub termination_b_id: Uuid,
pub label: Option<String>,
pub color: Option<String>,
pub length: Option<Option<i32>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableCableRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidtermination_a_type: Stringtermination_b_type: Stringlength_unit: Option<LengthUnitEnum>type: Option<CableTypeChoices>termination_a_id: Uuidtermination_b_id: Uuidlabel: Option<String>color: Option<String>RGB color in hexadecimal (e.g. 00ff00)
length: Option<Option<i32>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableCableRequest
impl BulkWritableCableRequest
Sourcepub fn new(
id: Uuid,
termination_a_type: String,
termination_b_type: String,
termination_a_id: Uuid,
termination_b_id: Uuid,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableCableRequest
pub fn new( id: Uuid, termination_a_type: String, termination_b_type: String, termination_a_id: Uuid, termination_b_id: Uuid, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableCableRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.