pub struct BulkWritableCloudNetworkRequest {
pub id: Uuid,
pub extra_config: Option<Option<Value>>,
pub name: String,
pub description: Option<String>,
pub cloud_resource_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub cloud_account: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub parent: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableCloudNetworkRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidextra_config: Option<Option<Value>>name: Stringdescription: Option<String>cloud_resource_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>cloud_account: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>parent: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableCloudNetworkRequest
impl BulkWritableCloudNetworkRequest
Sourcepub fn new(
id: Uuid,
name: String,
cloud_resource_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
cloud_account: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableCloudNetworkRequest
pub fn new( id: Uuid, name: String, cloud_resource_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, cloud_account: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableCloudNetworkRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.