pub struct BulkWritableConfigContextRequest {Show 20 fields
pub id: Uuid,
pub owner_content_type: Option<Option<String>>,
pub name: String,
pub owner_object_id: Option<Option<Uuid>>,
pub weight: Option<i32>,
pub description: Option<String>,
pub is_active: Option<bool>,
pub data: Option<Value>,
pub config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>,
pub locations: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub roles: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub device_types: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub device_redundancy_groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub platforms: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub cluster_groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub clusters: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub tenant_groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub tenants: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub device_families: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableConfigContextRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidowner_content_type: Option<Option<String>>name: Stringowner_object_id: Option<Option<Uuid>>weight: Option<i32>description: Option<String>is_active: Option<bool>data: Option<Value>config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>locations: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>roles: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>device_types: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>device_redundancy_groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>platforms: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>cluster_groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>clusters: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>tenant_groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>tenants: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>device_families: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl BulkWritableConfigContextRequest
impl BulkWritableConfigContextRequest
Sourcepub fn new(
id: Uuid,
name: String,
data: Option<Value>,
) -> BulkWritableConfigContextRequest
pub fn new( id: Uuid, name: String, data: Option<Value>, ) -> BulkWritableConfigContextRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)