pub struct BulkWritableConfigContextRequestConfigContextSchema {
pub id: Option<Box<ApprovalWorkflowApprovalWorkflowDefinitionId>>,
pub object_type: Option<String>,
pub url: Option<String>,
}Expand description
BulkWritableConfigContextRequestConfigContextSchema : Optional schema to validate the structure of the data
Fields
id: Option<Box<ApprovalWorkflowApprovalWorkflowDefinitionId>>object_type: Option<String>url: Option<String>Implementations
Sourceimpl BulkWritableConfigContextRequestConfigContextSchema
impl BulkWritableConfigContextRequestConfigContextSchema
Sourcepub fn new() -> BulkWritableConfigContextRequestConfigContextSchema
pub fn new() -> BulkWritableConfigContextRequestConfigContextSchema
Optional schema to validate the structure of the data