BulkWritableConfigContextSchemaRequest

Struct BulkWritableConfigContextSchemaRequest 

pub struct BulkWritableConfigContextSchemaRequest {
    pub id: Uuid,
    pub owner_content_type: Option<Option<String>>,
    pub name: String,
    pub description: Option<String>,
    pub data_schema: Option<Value>,
    pub owner_object_id: Option<Option<Uuid>>,
    pub custom_fields: Option<HashMap<String, Value>>,
    pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}
BulkWritableConfigContextSchemaRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Uuidowner_content_type: Option<Option<String>>name: Stringdescription: Option<String>data_schema: Option<Value>

A JSON Schema document which is used to validate a config context object.

owner_object_id: Option<Option<Uuid>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>

Implementations

Source

impl BulkWritableConfigContextSchemaRequest

pub fn new( id: Uuid, name: String, data_schema: Option<Value>, ) -> BulkWritableConfigContextSchemaRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.