pub struct BulkWritableConsolePortRequest {
pub id: Uuid,
pub type: Option<ConsolePortTypeChoices>,
pub name: String,
pub label: Option<String>,
pub description: Option<String>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableConsolePortRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidtype: Option<ConsolePortTypeChoices>name: Stringlabel: Option<String>Physical label
description: Option<String>device: Option<Option<Box<ApprovalWorkflowUser>>>module: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableConsolePortRequest
impl BulkWritableConsolePortRequest
Sourcepub fn new(id: Uuid, name: String) -> BulkWritableConsolePortRequest
pub fn new(id: Uuid, name: String) -> BulkWritableConsolePortRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.