Module bulk_writable_controller_managed_device_group_request

Module bulk_writable_controller_managed_device_group_request 

Structs

BulkWritableControllerManagedDeviceGroupRequest
BulkWritableControllerManagedDeviceGroupRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.