pub struct BulkWritableControllerManagedDeviceGroupRequest {
pub id: Uuid,
pub capabilities: Option<Option<Vec<CapabilitiesEnum>>>,
pub name: String,
pub description: Option<String>,
pub weight: Option<i32>,
pub parent: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller: Box<BulkWritableControllerManagedDeviceGroupRequestController>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableControllerManagedDeviceGroupRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidcapabilities: Option<Option<Vec<CapabilitiesEnum>>>name: StringName of the controller device group
description: Option<String>weight: Option<i32>Weight of the controller device group, used to sort the groups within its parent group
parent: Option<Option<Box<ApprovalWorkflowUser>>>controller: Box<BulkWritableControllerManagedDeviceGroupRequestController>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableControllerManagedDeviceGroupRequest
impl BulkWritableControllerManagedDeviceGroupRequest
Sourcepub fn new(
id: Uuid,
name: String,
controller: BulkWritableControllerManagedDeviceGroupRequestController,
) -> BulkWritableControllerManagedDeviceGroupRequest
pub fn new( id: Uuid, name: String, controller: BulkWritableControllerManagedDeviceGroupRequestController, ) -> BulkWritableControllerManagedDeviceGroupRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.