pub struct BulkWritableControllerRequest {Show 15 fields
pub id: Uuid,
pub capabilities: Option<Option<Vec<CapabilitiesEnum>>>,
pub name: String,
pub description: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub platform: Option<Option<Box<ApprovalWorkflowUser>>>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub external_integration: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller_device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller_device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableControllerRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidcapabilities: Option<Option<Vec<CapabilitiesEnum>>>name: Stringdescription: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>platform: Option<Option<Box<ApprovalWorkflowUser>>>role: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>external_integration: Option<Option<Box<ApprovalWorkflowUser>>>controller_device: Option<Option<Box<ApprovalWorkflowUser>>>controller_device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableControllerRequest
impl BulkWritableControllerRequest
Sourcepub fn new(
id: Uuid,
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableControllerRequest
pub fn new( id: Uuid, name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableControllerRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.