pub struct BulkWritableCustomLinkRequest {
pub id: Uuid,
pub content_type: String,
pub name: String,
pub text: String,
pub target_url: String,
pub weight: Option<i32>,
pub group_name: Option<String>,
pub button_class: Option<ButtonClassEnum>,
pub new_window: bool,
}Expand description
BulkWritableCustomLinkRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidcontent_type: Stringname: Stringtext: StringJinja2 template code for link text. Reference the object as {{ obj }} such as {{ obj.platform.name }}. Links which render as empty text will not be displayed.
target_url: StringJinja2 template code for link URL. Reference the object as {{ obj }} such as {{ obj.platform.name }}.
weight: Option<i32>group_name: Option<String>Links with the same group will appear as a dropdown menu
new_window: boolForce link to open in a new window
Implementations
Sourceimpl BulkWritableCustomLinkRequest
impl BulkWritableCustomLinkRequest
Sourcepub fn new(
id: Uuid,
content_type: String,
name: String,
text: String,
target_url: String,
new_window: bool,
) -> BulkWritableCustomLinkRequest
pub fn new( id: Uuid, content_type: String, name: String, text: String, target_url: String, new_window: bool, ) -> BulkWritableCustomLinkRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)