pub struct BulkWritableGitRepositoryRequest {
pub id: Uuid,
pub provided_contents: Option<Vec<BulkWritableGitRepositoryRequestProvidedContentsInner>>,
pub name: String,
pub slug: Option<String>,
pub remote_url: String,
pub branch: Option<String>,
pub current_head: Option<String>,
pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableGitRepositoryRequest : Git repositories defined as a data source.
Fields
id: Uuidprovided_contents: Option<Vec<BulkWritableGitRepositoryRequestProvidedContentsInner>>name: Stringslug: Option<String>Internal field name. Please use underscores rather than dashes in this key.
remote_url: StringOnly HTTP and HTTPS URLs are presently supported
branch: Option<String>Branch, tag, or commit
current_head: Option<String>Commit hash of the most recent fetch from the selected branch. Used for syncing between workers.
secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations