pub struct BulkWritableImageAttachmentRequest {
pub id: Uuid,
pub content_type: String,
pub object_id: Uuid,
pub image: PathBuf,
pub image_height: i32,
pub image_width: i32,
pub name: Option<String>,
}Expand description
BulkWritableImageAttachmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidcontent_type: Stringobject_id: Uuidimage: PathBufimage_height: i32image_width: i32name: Option<String>Implementations
Sourceimpl BulkWritableImageAttachmentRequest
impl BulkWritableImageAttachmentRequest
Sourcepub fn new(
id: Uuid,
content_type: String,
object_id: Uuid,
image: PathBuf,
image_height: i32,
image_width: i32,
) -> BulkWritableImageAttachmentRequest
pub fn new( id: Uuid, content_type: String, object_id: Uuid, image: PathBuf, image_height: i32, image_width: i32, ) -> BulkWritableImageAttachmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)