pub struct BulkWritableInterfaceVdcAssignmentRequest {
pub id: Uuid,
pub virtual_device_context: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub interface: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
BulkWritableInterfaceVdcAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidvirtual_device_context: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>interface: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl BulkWritableInterfaceVdcAssignmentRequest
impl BulkWritableInterfaceVdcAssignmentRequest
Sourcepub fn new(
id: Uuid,
virtual_device_context: ApprovalWorkflowStageResponseApprovalWorkflowStage,
interface: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableInterfaceVdcAssignmentRequest
pub fn new( id: Uuid, virtual_device_context: ApprovalWorkflowStageResponseApprovalWorkflowStage, interface: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableInterfaceVdcAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)