pub struct BulkWritableIpAddressToInterfaceRequest {
pub id: Uuid,
pub is_source: Option<bool>,
pub is_destination: Option<bool>,
pub is_default: Option<bool>,
pub is_preferred: Option<bool>,
pub is_primary: Option<bool>,
pub is_secondary: Option<bool>,
pub is_standby: Option<bool>,
pub ip_address: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub interface: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vm_interface: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
BulkWritableIpAddressToInterfaceRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidis_source: Option<bool>Is source address on interface
is_destination: Option<bool>Is destination address on interface
is_default: Option<bool>Is default address on interface
is_preferred: Option<bool>Is preferred address on interface
is_primary: Option<bool>Is primary address on interface
is_secondary: Option<bool>Is secondary address on interface
is_standby: Option<bool>Is standby address on interface
ip_address: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>interface: Option<Option<Box<ApprovalWorkflowUser>>>vm_interface: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl BulkWritableIpAddressToInterfaceRequest
impl BulkWritableIpAddressToInterfaceRequest
Sourcepub fn new(
id: Uuid,
ip_address: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableIpAddressToInterfaceRequest
pub fn new( id: Uuid, ip_address: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableIpAddressToInterfaceRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)