pub struct BulkWritableJobQueueAssignmentRequest {
pub id: Uuid,
pub job: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub job_queue: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
BulkWritableJobQueueAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidjob: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>job_queue: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl BulkWritableJobQueueAssignmentRequest
impl BulkWritableJobQueueAssignmentRequest
Sourcepub fn new(
id: Uuid,
job: ApprovalWorkflowStageResponseApprovalWorkflowStage,
job_queue: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableJobQueueAssignmentRequest
pub fn new( id: Uuid, job: ApprovalWorkflowStageResponseApprovalWorkflowStage, job_queue: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableJobQueueAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)