BulkWritableJobQueueRequest

Struct BulkWritableJobQueueRequest 

pub struct BulkWritableJobQueueRequest {
    pub id: Uuid,
    pub name: String,
    pub description: Option<String>,
    pub queue_type: QueueTypeEnum,
    pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
    pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
    pub custom_fields: Option<HashMap<String, Value>>,
    pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}
BulkWritableJobQueueRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Uuidname: Stringdescription: Option<String>queue_type: QueueTypeEnumtenant: Option<Option<Box<ApprovalWorkflowUser>>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>

Implementations

Source

impl BulkWritableJobQueueRequest

pub fn new( id: Uuid, name: String, queue_type: QueueTypeEnum, ) -> BulkWritableJobQueueRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.