pub struct BulkWritableModuleBayRequestModuleFamily {
pub id: Option<Box<ApprovalWorkflowApprovalWorkflowDefinitionId>>,
pub object_type: Option<String>,
pub url: Option<String>,
}Expand description
BulkWritableModuleBayRequestModuleFamily : Module family that can be installed in this bay
Fields
id: Option<Box<ApprovalWorkflowApprovalWorkflowDefinitionId>>object_type: Option<String>url: Option<String>Implementations
Sourceimpl BulkWritableModuleBayRequestModuleFamily
impl BulkWritableModuleBayRequestModuleFamily
Sourcepub fn new() -> BulkWritableModuleBayRequestModuleFamily
pub fn new() -> BulkWritableModuleBayRequestModuleFamily
Module family that can be installed in this bay