pub struct BulkWritableModuleBayTemplateRequestModuleFamily {
pub id: Option<Box<ApprovalWorkflowApprovalWorkflowDefinitionId>>,
pub object_type: Option<String>,
pub url: Option<String>,
}Expand description
BulkWritableModuleBayTemplateRequestModuleFamily : Module family that can be installed in this bay. Leave blank for no restriction.
Fields
id: Option<Box<ApprovalWorkflowApprovalWorkflowDefinitionId>>object_type: Option<String>url: Option<String>Implementations
Sourceimpl BulkWritableModuleBayTemplateRequestModuleFamily
impl BulkWritableModuleBayTemplateRequestModuleFamily
Sourcepub fn new() -> BulkWritableModuleBayTemplateRequestModuleFamily
pub fn new() -> BulkWritableModuleBayTemplateRequestModuleFamily
Module family that can be installed in this bay. Leave blank for no restriction.