pub struct BulkWritableModuleRequest {
pub id: Uuid,
pub serial: Option<Option<String>>,
pub asset_tag: Option<Option<String>>,
pub module_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub parent_module_bay: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub location: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableModuleRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidserial: Option<Option<String>>asset_tag: Option<Option<String>>A unique tag used to identify this module
module_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>parent_module_bay: Option<Option<Box<ApprovalWorkflowUser>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>location: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableModuleRequest
impl BulkWritableModuleRequest
Sourcepub fn new(
id: Uuid,
module_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableModuleRequest
pub fn new( id: Uuid, module_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableModuleRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.