pub struct BulkWritableObjectMetadataRequest {
pub id: Uuid,
pub assigned_object_type: String,
pub value: Option<Option<Value>>,
pub scoped_fields: Option<Option<Value>>,
pub assigned_object_id: Uuid,
pub metadata_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub contact: Option<Option<Box<ApprovalWorkflowUser>>>,
pub team: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
BulkWritableObjectMetadataRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidassigned_object_type: Stringvalue: Option<Option<Value>>scoped_fields: Option<Option<Value>>List of scoped fields, only direct fields on the model
assigned_object_id: Uuidmetadata_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>contact: Option<Option<Box<ApprovalWorkflowUser>>>team: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl BulkWritableObjectMetadataRequest
impl BulkWritableObjectMetadataRequest
Sourcepub fn new(
id: Uuid,
assigned_object_type: String,
assigned_object_id: Uuid,
metadata_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableObjectMetadataRequest
pub fn new( id: Uuid, assigned_object_type: String, assigned_object_id: Uuid, metadata_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableObjectMetadataRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)