Module bulk_writable_platform_request

Module bulk_writable_platform_request 

Structs

BulkWritablePlatformRequest
BulkWritablePlatformRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.