pub struct BulkWritablePrefixLocationAssignmentRequest {
pub id: Uuid,
pub prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
BulkWritablePrefixLocationAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidprefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl BulkWritablePrefixLocationAssignmentRequest
impl BulkWritablePrefixLocationAssignmentRequest
Sourcepub fn new(
id: Uuid,
prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritablePrefixLocationAssignmentRequest
pub fn new( id: Uuid, prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritablePrefixLocationAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)