pub struct BulkWritablePrefixRequest {Show 16 fields
pub id: Uuid,
pub prefix: String,
pub type: Option<PrefixTypeChoices>,
pub location: Option<Option<Box<BulkWritablePrefixRequestLocation>>>,
pub date_allocated: Option<Option<String>>,
pub description: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent: Option<Option<Box<BulkWritablePrefixRequestParent>>>,
pub namespace: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vlan: Option<Option<Box<ApprovalWorkflowUser>>>,
pub rir: Option<Option<Box<BulkWritablePrefixRequestRir>>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
BulkWritablePrefixRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidprefix: Stringtype: Option<PrefixTypeChoices>location: Option<Option<Box<BulkWritablePrefixRequestLocation>>>date_allocated: Option<Option<String>>Date this prefix was allocated to an RIR, reserved in IPAM, etc.
description: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>parent: Option<Option<Box<BulkWritablePrefixRequestParent>>>namespace: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>vlan: Option<Option<Box<ApprovalWorkflowUser>>>rir: Option<Option<Box<BulkWritablePrefixRequestRir>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritablePrefixRequest
impl BulkWritablePrefixRequest
Sourcepub fn new(
id: Uuid,
prefix: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritablePrefixRequest
pub fn new( id: Uuid, prefix: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritablePrefixRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.