pub struct BulkWritableSoftwareImageFileRequest {Show 13 fields
pub id: Uuid,
pub image_file_name: String,
pub image_file_checksum: Option<String>,
pub hashing_algorithm: Option<Box<BulkWritableSoftwareImageFileRequestHashingAlgorithm>>,
pub image_file_size: Option<Option<i64>>,
pub download_url: Option<String>,
pub default_image: Option<bool>,
pub software_version: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub external_integration: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableSoftwareImageFileRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidimage_file_name: Stringimage_file_checksum: Option<String>hashing_algorithm: Option<Box<BulkWritableSoftwareImageFileRequestHashingAlgorithm>>image_file_size: Option<Option<i64>>Image file size in bytes
download_url: Option<String>default_image: Option<bool>Is the default image for this software version
software_version: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>external_integration: Option<Option<Box<ApprovalWorkflowUser>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableSoftwareImageFileRequest
impl BulkWritableSoftwareImageFileRequest
Sourcepub fn new(
id: Uuid,
image_file_name: String,
software_version: ApprovalWorkflowStageResponseApprovalWorkflowStage,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableSoftwareImageFileRequest
pub fn new( id: Uuid, image_file_name: String, software_version: ApprovalWorkflowStageResponseApprovalWorkflowStage, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableSoftwareImageFileRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.