pub struct BulkWritableSupportedDataRateRequest {
pub id: Uuid,
pub standard: StandardEnum,
pub rate: i32,
pub mcs_index: Option<Option<i32>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableSupportedDataRateRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidstandard: StandardEnumrate: i32mcs_index: Option<Option<i32>>The Modulation and Coding Scheme (MCS) index is a value used in wireless communications to define the modulation type, coding rate, and number of spatial streams used in a transmission.
custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableSupportedDataRateRequest
impl BulkWritableSupportedDataRateRequest
Sourcepub fn new(
id: Uuid,
standard: StandardEnum,
rate: i32,
) -> BulkWritableSupportedDataRateRequest
pub fn new( id: Uuid, standard: StandardEnum, rate: i32, ) -> BulkWritableSupportedDataRateRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.