pub struct BulkWritableVmInterfaceRequest {Show 18 fields
pub id: Uuid,
pub mode: Option<InterfaceModeChoices>,
pub mac_address: Option<Option<String>>,
pub enabled: Option<bool>,
pub mtu: Option<Option<i32>>,
pub name: String,
pub description: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>,
pub bridge: Option<Option<Box<BridgeInterface>>>,
pub virtual_machine: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vrf: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tagged_vlans: Option<Vec<TaggedVlans>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
BulkWritableVmInterfaceRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidmode: Option<InterfaceModeChoices>mac_address: Option<Option<String>>enabled: Option<bool>mtu: Option<Option<i32>>name: Stringdescription: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>bridge: Option<Option<Box<BridgeInterface>>>virtual_machine: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>vrf: Option<Option<Box<ApprovalWorkflowUser>>>tagged_vlans: Option<Vec<TaggedVlans>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl BulkWritableVmInterfaceRequest
impl BulkWritableVmInterfaceRequest
Sourcepub fn new(
id: Uuid,
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
virtual_machine: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableVmInterfaceRequest
pub fn new( id: Uuid, name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, virtual_machine: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableVmInterfaceRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.