pub struct BulkWritableVrfPrefixAssignmentRequest {
pub id: Uuid,
pub vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
BulkWritableVrfPrefixAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidvrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl BulkWritableVrfPrefixAssignmentRequest
impl BulkWritableVrfPrefixAssignmentRequest
Sourcepub fn new(
id: Uuid,
vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage,
prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> BulkWritableVrfPrefixAssignmentRequest
pub fn new( id: Uuid, vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage, prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> BulkWritableVrfPrefixAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)