CloudAccountRequest

Struct CloudAccountRequest 

pub struct CloudAccountRequest {
    pub id: Option<Uuid>,
    pub name: String,
    pub description: Option<String>,
    pub account_number: String,
    pub provider: Box<BulkWritableCloudAccountRequestProvider>,
    pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>,
    pub custom_fields: Option<HashMap<String, Value>>,
    pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
    pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}
CloudAccountRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>name: String

The name of this Cloud Account.

description: Option<String>account_number: String

The account identifier of this Cloud Account.

provider: Box<BulkWritableCloudAccountRequestProvider>secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>

Implementations

Source

impl CloudAccountRequest

pub fn new( name: String, account_number: String, provider: BulkWritableCloudAccountRequestProvider, ) -> CloudAccountRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.