pub struct CloudService {Show 15 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub extra_config: Option<Option<Value>>,
pub name: String,
pub description: Option<String>,
pub cloud_resource_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub cloud_account: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
CloudService : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>extra_config: Option<Option<Value>>name: Stringdescription: Option<String>cloud_resource_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>cloud_account: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl CloudService
impl CloudService
Sourcepub fn new(
name: String,
cloud_resource_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> CloudService
pub fn new( name: String, cloud_resource_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> CloudService
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.