pub struct CloudServiceNetworkAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub cloud_network: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub cloud_service: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
CloudServiceNetworkAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>cloud_network: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>cloud_service: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl CloudServiceNetworkAssignment
impl CloudServiceNetworkAssignment
Sourcepub fn new(
cloud_network: ApprovalWorkflowStageResponseApprovalWorkflowStage,
cloud_service: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> CloudServiceNetworkAssignment
pub fn new( cloud_network: ApprovalWorkflowStageResponseApprovalWorkflowStage, cloud_service: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> CloudServiceNetworkAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)