pub struct CloudServiceRequest {
pub id: Option<Uuid>,
pub extra_config: Option<Option<Value>>,
pub name: String,
pub description: Option<String>,
pub cloud_resource_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub cloud_account: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
CloudServiceRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>extra_config: Option<Option<Value>>name: Stringdescription: Option<String>cloud_resource_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>cloud_account: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl CloudServiceRequest
impl CloudServiceRequest
Sourcepub fn new(
name: String,
cloud_resource_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> CloudServiceRequest
pub fn new( name: String, cloud_resource_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> CloudServiceRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.