pub struct ClusterGroupRequest {
pub id: Option<Uuid>,
pub name: String,
pub description: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
ClusterGroupRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Stringdescription: Option<String>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl ClusterGroupRequest
impl ClusterGroupRequest
Sourcepub fn new(name: String) -> ClusterGroupRequest
pub fn new(name: String) -> ClusterGroupRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.