pub struct ConfigContext {Show 18 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub owner_content_type: Option<Option<String>>,
pub owner: Option<Option<Box<ConfigContextOwner>>>,
pub name: String,
pub owner_object_id: Option<Option<Uuid>>,
pub weight: Option<i32>,
pub description: Option<String>,
pub is_active: Option<bool>,
pub data: Option<Value>,
pub config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
ConfigContext : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>owner_content_type: Option<Option<String>>owner: Option<Option<Box<ConfigContextOwner>>>name: Stringowner_object_id: Option<Option<Uuid>>weight: Option<i32>description: Option<String>is_active: Option<bool>data: Option<Value>config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>Implementations
Sourceimpl ConfigContext
impl ConfigContext
Sourcepub fn new(name: String, data: Option<Value>) -> ConfigContext
pub fn new(name: String, data: Option<Value>) -> ConfigContext
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)