ConfigContextSchema

Struct ConfigContextSchema 

pub struct ConfigContextSchema {
Show 15 fields pub id: Option<Uuid>, pub object_type: Option<String>, pub display: Option<String>, pub url: Option<String>, pub natural_slug: Option<String>, pub owner_content_type: Option<Option<String>>, pub owner: Option<Option<Box<ConfigContextSchemaOwner>>>, pub name: String, pub description: Option<String>, pub data_schema: Option<Value>, pub owner_object_id: Option<Option<Uuid>>, pub created: Option<Option<String>>, pub last_updated: Option<Option<String>>, pub notes_url: Option<String>, pub custom_fields: Option<HashMap<String, Value>>,
}
ConfigContextSchema : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>object_type: Option<String>display: Option<String>

Human friendly display value

url: Option<String>natural_slug: Option<String>owner_content_type: Option<Option<String>>owner: Option<Option<Box<ConfigContextSchemaOwner>>>name: Stringdescription: Option<String>data_schema: Option<Value>

A JSON Schema document which is used to validate a config context object.

owner_object_id: Option<Option<Uuid>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>

Implementations

Source

impl ConfigContextSchema

pub fn new(name: String, data_schema: Option<Value>) -> ConfigContextSchema

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.