pub struct ControllerManagedDeviceGroup {Show 17 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub capabilities: Option<Option<Vec<ControllerCapabilitiesInner>>>,
pub name: String,
pub description: Option<String>,
pub weight: Option<i32>,
pub parent: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller: Box<BulkWritableControllerManagedDeviceGroupRequestController>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
ControllerManagedDeviceGroup : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>capabilities: Option<Option<Vec<ControllerCapabilitiesInner>>>name: StringName of the controller device group
description: Option<String>weight: Option<i32>Weight of the controller device group, used to sort the groups within its parent group
parent: Option<Option<Box<ApprovalWorkflowUser>>>controller: Box<BulkWritableControllerManagedDeviceGroupRequestController>tenant: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl ControllerManagedDeviceGroup
impl ControllerManagedDeviceGroup
Sourcepub fn new(
name: String,
controller: BulkWritableControllerManagedDeviceGroupRequestController,
) -> ControllerManagedDeviceGroup
pub fn new( name: String, controller: BulkWritableControllerManagedDeviceGroupRequestController, ) -> ControllerManagedDeviceGroup
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.