pub struct ControllerManagedDeviceGroupRadioProfileAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub controller_managed_device_group: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub radio_profile: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
ControllerManagedDeviceGroupRadioProfileAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>controller_managed_device_group: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>radio_profile: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl ControllerManagedDeviceGroupRadioProfileAssignment
impl ControllerManagedDeviceGroupRadioProfileAssignment
Sourcepub fn new(
controller_managed_device_group: ApprovalWorkflowStageResponseApprovalWorkflowStage,
radio_profile: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> ControllerManagedDeviceGroupRadioProfileAssignment
pub fn new( controller_managed_device_group: ApprovalWorkflowStageResponseApprovalWorkflowStage, radio_profile: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> ControllerManagedDeviceGroupRadioProfileAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)