pub struct ControllerManagedDeviceGroupRadioProfileAssignmentRequest {
pub id: Option<Uuid>,
pub controller_managed_device_group: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub radio_profile: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
ControllerManagedDeviceGroupRadioProfileAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>controller_managed_device_group: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>radio_profile: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl ControllerManagedDeviceGroupRadioProfileAssignmentRequest
impl ControllerManagedDeviceGroupRadioProfileAssignmentRequest
Sourcepub fn new(
controller_managed_device_group: ApprovalWorkflowStageResponseApprovalWorkflowStage,
radio_profile: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> ControllerManagedDeviceGroupRadioProfileAssignmentRequest
pub fn new( controller_managed_device_group: ApprovalWorkflowStageResponseApprovalWorkflowStage, radio_profile: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> ControllerManagedDeviceGroupRadioProfileAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)