Device

Struct Device 

pub struct Device {
Show 38 fields pub id: Option<Uuid>, pub object_type: Option<String>, pub display: Option<String>, pub url: Option<String>, pub natural_slug: Option<String>, pub face: Option<Box<DeviceFace>>, pub local_config_context_data: Option<Option<Value>>, pub local_config_context_data_owner_object_id: Option<Option<Uuid>>, pub name: Option<Option<String>>, pub serial: Option<String>, pub asset_tag: Option<Option<String>>, pub position: Option<Option<i32>>, pub device_redundancy_group_priority: Option<Option<i32>>, pub vc_position: Option<Option<i32>>, pub vc_priority: Option<Option<i32>>, pub comments: Option<String>, pub local_config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>, pub local_config_context_data_owner_content_type: Option<Option<Box<ApprovalWorkflowUser>>>, pub device_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub role: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>, pub platform: Option<Option<Box<ApprovalWorkflowUser>>>, pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub rack: Option<Option<Box<ApprovalWorkflowUser>>>, pub primary_ip4: Option<Option<Box<PrimaryIpv4>>>, pub primary_ip6: Option<Option<Box<PrimaryIpv6>>>, pub virtual_chassis: Option<Option<Box<ApprovalWorkflowUser>>>, pub device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub software_version: Option<Option<Box<BulkWritableDeviceRequestSoftwareVersion>>>, pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub controller_managed_device_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub created: Option<Option<String>>, pub last_updated: Option<Option<String>>, pub notes_url: Option<String>, pub custom_fields: Option<HashMap<String, Value>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub parent_bay: Option<Option<Box<ApprovalWorkflowUser>>>,
}
Device : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>object_type: Option<String>display: Option<String>

Human friendly display value

url: Option<String>natural_slug: Option<String>face: Option<Box<DeviceFace>>local_config_context_data: Option<Option<Value>>local_config_context_data_owner_object_id: Option<Option<Uuid>>name: Option<Option<String>>serial: Option<String>asset_tag: Option<Option<String>>

A unique tag used to identify this device

position: Option<Option<i32>>

The lowest-numbered unit occupied by the device

device_redundancy_group_priority: Option<Option<i32>>

The priority the device has in the device redundancy group.

vc_position: Option<Option<i32>>vc_priority: Option<Option<i32>>comments: Option<String>local_config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>local_config_context_data_owner_content_type: Option<Option<Box<ApprovalWorkflowUser>>>device_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>tenant: Option<Option<Box<ApprovalWorkflowUser>>>platform: Option<Option<Box<ApprovalWorkflowUser>>>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>rack: Option<Option<Box<ApprovalWorkflowUser>>>primary_ip4: Option<Option<Box<PrimaryIpv4>>>primary_ip6: Option<Option<Box<PrimaryIpv6>>>virtual_chassis: Option<Option<Box<ApprovalWorkflowUser>>>device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>software_version: Option<Option<Box<BulkWritableDeviceRequestSoftwareVersion>>>secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>controller_managed_device_group: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>parent_bay: Option<Option<Box<ApprovalWorkflowUser>>>

Implementations

Source

impl Device

pub fn new( device_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, role: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> Device

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.