pub struct DeviceType {Show 21 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub subdevice_role: Option<Box<DeviceTypeSubdeviceRole>>,
pub front_image: Option<Option<String>>,
pub rear_image: Option<Option<String>>,
pub device_count: Option<i32>,
pub model: String,
pub part_number: Option<String>,
pub u_height: Option<i32>,
pub is_full_depth: Option<bool>,
pub comments: Option<String>,
pub manufacturer: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub device_family: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
DeviceType : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>subdevice_role: Option<Box<DeviceTypeSubdeviceRole>>front_image: Option<Option<String>>rear_image: Option<Option<String>>device_count: Option<i32>model: Stringpart_number: Option<String>Discrete part number (optional)
u_height: Option<i32>is_full_depth: Option<bool>Device consumes both front and rear rack faces
comments: Option<String>manufacturer: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>device_family: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl DeviceType
impl DeviceType
Sourcepub fn new(
model: String,
manufacturer: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> DeviceType
pub fn new( model: String, manufacturer: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> DeviceType
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.