pub struct ExternalIntegration {Show 19 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub name: String,
pub remote_url: String,
pub verify_ssl: Option<bool>,
pub timeout: Option<i32>,
pub extra_config: Option<Option<Value>>,
pub http_method: Option<Box<BulkWritableExternalIntegrationRequestHttpMethod>>,
pub headers: Option<Option<Value>>,
pub ca_file_path: Option<String>,
pub secrets_group: Option<Option<Box<BulkWritableExternalIntegrationRequestSecretsGroup>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
ExternalIntegration : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>name: Stringremote_url: Stringverify_ssl: Option<bool>Verify SSL certificates when connecting to the remote system
timeout: Option<i32>Number of seconds to wait for a response
extra_config: Option<Option<Value>>Optional user-defined JSON data for this integration
http_method: Option<Box<BulkWritableExternalIntegrationRequestHttpMethod>>headers: Option<Option<Value>>Headers for the HTTP request
ca_file_path: Option<String>secrets_group: Option<Option<Box<BulkWritableExternalIntegrationRequestSecretsGroup>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl ExternalIntegration
impl ExternalIntegration
Sourcepub fn new(name: String, remote_url: String) -> ExternalIntegration
pub fn new(name: String, remote_url: String) -> ExternalIntegration
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.