pub struct FileProxy {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub name: String,
pub uploaded_at: Option<String>,
pub job_result: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
FileProxy : This base serializer implements common fields and logic for all ModelSerializers. Namely, it: - defines the display field which exposes a human friendly value for the given object. - ensures that id field is always present on the serializer as well. - ensures that created and last_updated fields are always present if applicable to this model and serializer. - ensures that object_type field is always present on the serializer which represents the content-type of this serializer’s associated model (e.g. "dcim.device"). This is required as the OpenAPI schema, using the PolymorphicProxySerializer class defined below, relies upon this field as a way to identify to the client which of several possible serializers are in use for a given attribute. - supports ?depth query parameter. It is passed in as nested_depth to the build_nested_field() function to enable the dynamic generation of nested serializers.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>name: Stringuploaded_at: Option<String>job_result: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl FileProxy
impl FileProxy
Sourcepub fn new(name: String) -> FileProxy
pub fn new(name: String) -> FileProxy
This base serializer implements common fields and logic for all ModelSerializers. Namely, it: - defines the display field which exposes a human friendly value for the given object. - ensures that id field is always present on the serializer as well. - ensures that created and last_updated fields are always present if applicable to this model and serializer. - ensures that object_type field is always present on the serializer which represents the content-type of this serializer’s associated model (e.g. "dcim.device"). This is required as the OpenAPI schema, using the PolymorphicProxySerializer class defined below, relies upon this field as a way to identify to the client which of several possible serializers are in use for a given attribute. - supports ?depth query parameter. It is passed in as nested_depth to the build_nested_field() function to enable the dynamic generation of nested serializers.