pub struct GitRepository {Show 17 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub provided_contents: Option<Vec<BulkWritableGitRepositoryRequestProvidedContentsInner>>,
pub name: String,
pub slug: Option<String>,
pub remote_url: String,
pub branch: Option<String>,
pub current_head: Option<String>,
pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
GitRepository : Git repositories defined as a data source.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>provided_contents: Option<Vec<BulkWritableGitRepositoryRequestProvidedContentsInner>>name: Stringslug: Option<String>Internal field name. Please use underscores rather than dashes in this key.
remote_url: StringOnly HTTP and HTTPS URLs are presently supported
branch: Option<String>Branch, tag, or commit
current_head: Option<String>Commit hash of the most recent fetch from the selected branch. Used for syncing between workers.
secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl GitRepository
impl GitRepository
Sourcepub fn new(name: String, remote_url: String) -> GitRepository
pub fn new(name: String, remote_url: String) -> GitRepository
Git repositories defined as a data source.