pub struct Interface {Show 38 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub cable_peer_type: Option<Option<String>>,
pub cable_peer: Option<Option<Box<CableTermination>>>,
pub natural_slug: Option<String>,
pub connected_endpoint_type: Option<Option<String>>,
pub connected_endpoint: Option<Option<Box<PathEndpoint>>>,
pub connected_endpoint_reachable: Option<Option<bool>>,
pub type: Box<InterfaceType>,
pub port_type: Option<Box<FrontPortType>>,
pub mode: Option<Box<InterfaceMode>>,
pub mac_address: Option<Option<String>>,
pub ip_address_count: Option<i32>,
pub speed: Option<Option<i32>>,
pub duplex: Option<Box<InterfaceDuplex>>,
pub name: String,
pub label: Option<String>,
pub description: Option<String>,
pub enabled: Option<bool>,
pub mtu: Option<Option<i32>>,
pub mgmt_only: Option<bool>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub cable: Option<Option<Box<CircuitCircuitTerminationA>>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>,
pub bridge: Option<Option<Box<BridgeInterface>>>,
pub lag: Option<Option<Box<ParentLag>>>,
pub untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vrf: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
Interface : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>cable_peer_type: Option<Option<String>>cable_peer: Option<Option<Box<CableTermination>>>natural_slug: Option<String>connected_endpoint_type: Option<Option<String>>connected_endpoint: Option<Option<Box<PathEndpoint>>>connected_endpoint_reachable: Option<Option<bool>>type: Box<InterfaceType>port_type: Option<Box<FrontPortType>>mode: Option<Box<InterfaceMode>>mac_address: Option<Option<String>>ip_address_count: Option<i32>speed: Option<Option<i32>>duplex: Option<Box<InterfaceDuplex>>name: Stringlabel: Option<String>Physical label
description: Option<String>enabled: Option<bool>mtu: Option<Option<i32>>mgmt_only: Option<bool>This interface is used only for out-of-band management
device: Option<Option<Box<ApprovalWorkflowUser>>>module: Option<Option<Box<ApprovalWorkflowUser>>>cable: Option<Option<Box<CircuitCircuitTerminationA>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>bridge: Option<Option<Box<BridgeInterface>>>lag: Option<Option<Box<ParentLag>>>untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>vrf: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl Interface
impl Interface
Sourcepub fn new(
type: InterfaceType,
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> Interface
pub fn new( type: InterfaceType, name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> Interface
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.