pub struct InterfaceConnection {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub interface_a: Option<Box<Interface>>,
pub interface_b: Box<Interface>,
pub connected_endpoint_reachable: Option<Option<bool>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
}Expand description
InterfaceConnection : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
interface_a: Option<Box<Interface>>interface_b: Box<Interface>connected_endpoint_reachable: Option<Option<bool>>created: Option<Option<String>>last_updated: Option<Option<String>>Implementations
Sourceimpl InterfaceConnection
impl InterfaceConnection
Sourcepub fn new(interface_b: Interface) -> InterfaceConnection
pub fn new(interface_b: Interface) -> InterfaceConnection
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)