pub struct InterfaceTemplate {Show 19 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub notes_url: Option<String>,
pub type: Box<InterfaceType>,
pub port_type: Option<Box<FrontPortType>>,
pub name: String,
pub label: Option<String>,
pub description: Option<String>,
pub mgmt_only: Option<bool>,
pub speed: Option<Option<i32>>,
pub duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>,
pub device_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
InterfaceTemplate : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>notes_url: Option<String>type: Box<InterfaceType>port_type: Option<Box<FrontPortType>>name: Stringlabel: Option<String>Physical label
description: Option<String>mgmt_only: Option<bool>speed: Option<Option<i32>>duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>device_type: Option<Option<Box<ApprovalWorkflowUser>>>module_type: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl InterfaceTemplate
impl InterfaceTemplate
Sourcepub fn new(type: InterfaceType, name: String) -> InterfaceTemplate
pub fn new(type: InterfaceType, name: String) -> InterfaceTemplate
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.