pub struct InterfaceVdcAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub virtual_device_context: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub interface: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
InterfaceVdcAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>virtual_device_context: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>interface: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl InterfaceVdcAssignment
impl InterfaceVdcAssignment
Sourcepub fn new(
virtual_device_context: ApprovalWorkflowStageResponseApprovalWorkflowStage,
interface: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> InterfaceVdcAssignment
pub fn new( virtual_device_context: ApprovalWorkflowStageResponseApprovalWorkflowStage, interface: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> InterfaceVdcAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)