pub struct IpAddress {Show 22 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub address: String,
pub host: Option<String>,
pub mask_length: Option<i32>,
pub type: Option<IpAddressTypeChoices>,
pub ip_version: Option<i32>,
pub dns_name: Option<String>,
pub description: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent: Option<Option<Box<BulkWritableIpAddressRequestParent>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub nat_inside: Option<Option<Box<NatInside>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
IpAddress : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>address: Stringhost: Option<String>IPv4 or IPv6 host address
mask_length: Option<i32>Length of the network mask, in bits.
type: Option<IpAddressTypeChoices>ip_version: Option<i32>dns_name: Option<String>Hostname or FQDN (not case-sensitive)
description: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>parent: Option<Option<Box<BulkWritableIpAddressRequestParent>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>nat_inside: Option<Option<Box<NatInside>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl IpAddress
impl IpAddress
Sourcepub fn new(
address: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> IpAddress
pub fn new( address: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> IpAddress
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.