pub struct IpAddressRequest {Show 14 fields
pub id: Option<Uuid>,
pub address: String,
pub namespace: Option<Box<BulkWritableIpAddressRequestNamespace>>,
pub type: Option<IpAddressTypeChoices>,
pub dns_name: Option<String>,
pub description: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent: Option<Option<Box<BulkWritableIpAddressRequestParent>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub nat_inside: Option<Option<Box<NatInside>>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
IpAddressRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>address: Stringnamespace: Option<Box<BulkWritableIpAddressRequestNamespace>>type: Option<IpAddressTypeChoices>dns_name: Option<String>Hostname or FQDN (not case-sensitive)
description: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>parent: Option<Option<Box<BulkWritableIpAddressRequestParent>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>nat_inside: Option<Option<Box<NatInside>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl IpAddressRequest
impl IpAddressRequest
Sourcepub fn new(
address: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> IpAddressRequest
pub fn new( address: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> IpAddressRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.