JobRequest

Struct JobRequest 

pub struct JobRequest {
Show 28 fields pub id: Option<Uuid>, pub grouping: String, pub name: String, pub description: Option<String>, pub enabled: Option<bool>, pub has_sensitive_variables: Option<bool>, pub is_singleton: Option<bool>, pub console_log_default: Option<bool>, pub hidden: Option<bool>, pub dryrun_default: Option<bool>, pub soft_time_limit: Option<f64>, pub time_limit: Option<f64>, pub grouping_override: Option<bool>, pub name_override: Option<bool>, pub console_log_default_override: Option<bool>, pub description_override: Option<bool>, pub dryrun_default_override: Option<bool>, pub hidden_override: Option<bool>, pub soft_time_limit_override: Option<bool>, pub time_limit_override: Option<bool>, pub has_sensitive_variables_override: Option<bool>, pub job_queues_override: Option<bool>, pub default_job_queue_override: Option<bool>, pub is_singleton_override: Option<bool>, pub default_job_queue: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub custom_fields: Option<HashMap<String, Value>>, pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}
JobRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>grouping: String

Human-readable grouping that this job belongs to

name: String

Human-readable name of this job

description: Option<String>

Markdown formatting and a limited subset of HTML are supported

enabled: Option<bool>

Whether this job can be executed by users

has_sensitive_variables: Option<bool>

Whether this job contains sensitive variables

is_singleton: Option<bool>

Whether this job should fail to run if another instance of this job is already running

console_log_default: Option<bool>

Whether the job defaults to running with console log argument set to true

hidden: Option<bool>

Whether the job defaults to not being shown in the UI

dryrun_default: Option<bool>

Whether the job defaults to running with dryrun argument set to true

soft_time_limit: Option<f64>

Maximum runtime in seconds before the job will receive a SoftTimeLimitExceeded exception.
Set to 0 to use Nautobot system default

time_limit: Option<f64>

Maximum runtime in seconds before the job will be forcibly terminated.
Set to 0 to use Nautobot system default

grouping_override: Option<bool>

If set, the configured grouping will remain even if the underlying Job source code changes

name_override: Option<bool>

If set, the configured name will remain even if the underlying Job source code changes

console_log_default_override: Option<bool>

If set, the configured console log default will remain even if the underlying Job source code changes

description_override: Option<bool>

If set, the configured description will remain even if the underlying Job source code changes

dryrun_default_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

hidden_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

soft_time_limit_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

time_limit_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

has_sensitive_variables_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

job_queues_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

default_job_queue_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

is_singleton_override: Option<bool>

If set, the configured value will remain even if the underlying Job source code changes

default_job_queue: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>

Implementations

Source

impl JobRequest

pub fn new( grouping: String, name: String, default_job_queue: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> JobRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.