pub struct MetadataChoice {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub value: String,
pub weight: Option<i32>,
pub metadata_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
}Expand description
MetadataChoice : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>value: Stringweight: Option<i32>Higher weights appear later in the list
metadata_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>created: Option<Option<String>>last_updated: Option<Option<String>>Implementations
Sourceimpl MetadataChoice
impl MetadataChoice
Sourcepub fn new(
value: String,
metadata_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> MetadataChoice
pub fn new( value: String, metadata_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> MetadataChoice
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)