pub struct MetadataChoiceRequest {
pub id: Option<Uuid>,
pub value: String,
pub weight: Option<i32>,
pub metadata_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
MetadataChoiceRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>value: Stringweight: Option<i32>Higher weights appear later in the list
metadata_type: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl MetadataChoiceRequest
impl MetadataChoiceRequest
Sourcepub fn new(
value: String,
metadata_type: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> MetadataChoiceRequest
pub fn new( value: String, metadata_type: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> MetadataChoiceRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)