pub struct ModuleBay {Show 18 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub requires_first_party_modules: Option<bool>,
pub name: String,
pub position: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub parent_device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent_module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_family: Option<Option<Box<BulkWritableModuleBayRequestModuleFamily>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
ModuleBay : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>requires_first_party_modules: Option<bool>This bay will only accept modules from the same manufacturer as the parent device or module
name: Stringposition: Option<String>The position of the module bay within the parent device/module
label: Option<String>Physical label
description: Option<String>parent_device: Option<Option<Box<ApprovalWorkflowUser>>>parent_module: Option<Option<Box<ApprovalWorkflowUser>>>module_family: Option<Option<Box<BulkWritableModuleBayRequestModuleFamily>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations