Module module_type

Module module_type 

Structs

ModuleType
ModuleType : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.