pub struct ModuleType {Show 17 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub front_image: Option<Option<String>>,
pub rear_image: Option<Option<String>>,
pub model: String,
pub part_number: Option<String>,
pub comments: Option<String>,
pub manufacturer: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub module_family: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
ModuleType : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>front_image: Option<Option<String>>rear_image: Option<Option<String>>model: Stringpart_number: Option<String>Discrete part number (optional)
comments: Option<String>manufacturer: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>module_family: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl ModuleType
impl ModuleType
Sourcepub fn new(
model: String,
manufacturer: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> ModuleType
pub fn new( model: String, manufacturer: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> ModuleType
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.