Module nested_controller

Module nested_controller 

Structs

NestedController
NestedController : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.