Module nested_controller_managed_device_group

Module nested_controller_managed_device_group 

Structs

NestedControllerManagedDeviceGroup
NestedControllerManagedDeviceGroup : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.