Module nested_device

Module nested_device 

Structs

NestedDevice
NestedDevice : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.