Module nested_interface

Module nested_interface 

Structs

NestedInterface
NestedInterface : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.