pub struct NestedInterfaceVdcAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub url: Option<String>,
}Expand description
NestedInterfaceVdcAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>url: Option<String>Implementations
Sourceimpl NestedInterfaceVdcAssignment
impl NestedInterfaceVdcAssignment
Sourcepub fn new() -> NestedInterfaceVdcAssignment
pub fn new() -> NestedInterfaceVdcAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)