pub struct NestedPrefix {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub url: Option<String>,
}Expand description
NestedPrefix : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>url: Option<String>Implementations
Sourceimpl NestedPrefix
impl NestedPrefix
Sourcepub fn new() -> NestedPrefix
pub fn new() -> NestedPrefix
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.