pub struct NestedRack {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub url: Option<String>,
}Expand description
NestedRack : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>url: Option<String>Implementations
Sourceimpl NestedRack
impl NestedRack
Sourcepub fn new() -> NestedRack
pub fn new() -> NestedRack
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.