Module nested_software_version

Module nested_software_version 

Structs

NestedSoftwareVersion
NestedSoftwareVersion : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.