Module nested_virtual_device_context

Module nested_virtual_device_context 

Structs

NestedVirtualDeviceContext
NestedVirtualDeviceContext : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.