pub struct PatchedBulkWritableControllerManagedDeviceGroupRequest {
pub id: Uuid,
pub capabilities: Option<Option<Vec<CapabilitiesEnum>>>,
pub name: Option<String>,
pub description: Option<String>,
pub weight: Option<i32>,
pub parent: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller: Option<Box<BulkWritableControllerManagedDeviceGroupRequestController>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedBulkWritableControllerManagedDeviceGroupRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidcapabilities: Option<Option<Vec<CapabilitiesEnum>>>name: Option<String>Name of the controller device group
description: Option<String>weight: Option<i32>Weight of the controller device group, used to sort the groups within its parent group
parent: Option<Option<Box<ApprovalWorkflowUser>>>controller: Option<Box<BulkWritableControllerManagedDeviceGroupRequestController>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedBulkWritableControllerManagedDeviceGroupRequest
impl PatchedBulkWritableControllerManagedDeviceGroupRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableControllerManagedDeviceGroupRequest
pub fn new(id: Uuid) -> PatchedBulkWritableControllerManagedDeviceGroupRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.