pub struct PatchedBulkWritableGraphQlQueryRequest {
pub id: Uuid,
pub owner_content_type: Option<Option<String>>,
pub owner_object_id: Option<Option<Uuid>>,
pub name: Option<String>,
pub query: Option<String>,
}Expand description
PatchedBulkWritableGraphQlQueryRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidowner_content_type: Option<Option<String>>owner_object_id: Option<Option<Uuid>>name: Option<String>query: Option<String>Implementations
Sourceimpl PatchedBulkWritableGraphQlQueryRequest
impl PatchedBulkWritableGraphQlQueryRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableGraphQlQueryRequest
pub fn new(id: Uuid) -> PatchedBulkWritableGraphQlQueryRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)