pub struct PatchedBulkWritableInterfaceTemplateRequest {Show 13 fields
pub id: Uuid,
pub type: Option<InterfaceTypeChoices>,
pub port_type: Option<PortTypeChoices>,
pub name: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub mgmt_only: Option<bool>,
pub speed: Option<Option<i32>>,
pub duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>,
pub device_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedBulkWritableInterfaceTemplateRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidtype: Option<InterfaceTypeChoices>port_type: Option<PortTypeChoices>name: Option<String>label: Option<String>Physical label
description: Option<String>mgmt_only: Option<bool>speed: Option<Option<i32>>duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>device_type: Option<Option<Box<ApprovalWorkflowUser>>>module_type: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedBulkWritableInterfaceTemplateRequest
impl PatchedBulkWritableInterfaceTemplateRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableInterfaceTemplateRequest
pub fn new(id: Uuid) -> PatchedBulkWritableInterfaceTemplateRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.