pub struct PatchedBulkWritableInterfaceVdcAssignmentRequest {
pub id: Uuid,
pub virtual_device_context: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub interface: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedBulkWritableInterfaceVdcAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidvirtual_device_context: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>interface: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedBulkWritableInterfaceVdcAssignmentRequest
impl PatchedBulkWritableInterfaceVdcAssignmentRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableInterfaceVdcAssignmentRequest
pub fn new(id: Uuid) -> PatchedBulkWritableInterfaceVdcAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)