pub struct PatchedBulkWritableJobQueueAssignmentRequest {
pub id: Uuid,
pub job: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub job_queue: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedBulkWritableJobQueueAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidjob: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>job_queue: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedBulkWritableJobQueueAssignmentRequest
impl PatchedBulkWritableJobQueueAssignmentRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableJobQueueAssignmentRequest
pub fn new(id: Uuid) -> PatchedBulkWritableJobQueueAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)