pub struct PatchedBulkWritableObjectMetadataRequest {
pub id: Uuid,
pub assigned_object_type: Option<String>,
pub value: Option<Option<Value>>,
pub scoped_fields: Option<Option<Value>>,
pub assigned_object_id: Option<Uuid>,
pub metadata_type: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub contact: Option<Option<Box<ApprovalWorkflowUser>>>,
pub team: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
PatchedBulkWritableObjectMetadataRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidassigned_object_type: Option<String>value: Option<Option<Value>>scoped_fields: Option<Option<Value>>List of scoped fields, only direct fields on the model
assigned_object_id: Option<Uuid>metadata_type: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>contact: Option<Option<Box<ApprovalWorkflowUser>>>team: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl PatchedBulkWritableObjectMetadataRequest
impl PatchedBulkWritableObjectMetadataRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableObjectMetadataRequest
pub fn new(id: Uuid) -> PatchedBulkWritableObjectMetadataRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)