pub struct PatchedBulkWritablePlatformRequest {
pub id: Uuid,
pub name: Option<String>,
pub network_driver: Option<String>,
pub napalm_driver: Option<String>,
pub napalm_args: Option<Option<Value>>,
pub description: Option<String>,
pub manufacturer: Option<Option<Box<BulkWritablePlatformRequestManufacturer>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedBulkWritablePlatformRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidname: Option<String>network_driver: Option<String>The normalized network driver to use when interacting with devices, e.g. cisco_ios, arista_eos, etc. Library-specific driver names will be derived from this setting as appropriate
napalm_driver: Option<String>The name of the NAPALM driver to use when Nautobot internals interact with devices
napalm_args: Option<Option<Value>>Additional arguments to pass when initiating the NAPALM driver (JSON format)
description: Option<String>manufacturer: Option<Option<Box<BulkWritablePlatformRequestManufacturer>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedBulkWritablePlatformRequest
impl PatchedBulkWritablePlatformRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritablePlatformRequest
pub fn new(id: Uuid) -> PatchedBulkWritablePlatformRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.