pub struct PatchedBulkWritableRegularExpressionValidationRuleRequest {
pub id: Uuid,
pub content_type: Option<String>,
pub name: Option<String>,
pub field: Option<String>,
pub enabled: Option<bool>,
pub error_message: Option<String>,
pub regular_expression: Option<String>,
pub context_processing: Option<bool>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedBulkWritableRegularExpressionValidationRuleRequest : Serializer for RegularExpressionValidationRule objects.
Fields
id: Uuidcontent_type: Option<String>name: Option<String>field: Option<String>enabled: Option<bool>error_message: Option<String>Optional error message to display when validation fails.
regular_expression: Option<String>context_processing: Option<bool>When enabled, the regular expression value is first processed as a Jinja2 template with access to the context of the data being validated in a variable named object.
custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedBulkWritableRegularExpressionValidationRuleRequest
impl PatchedBulkWritableRegularExpressionValidationRuleRequest
Sourcepub fn new(
id: Uuid,
) -> PatchedBulkWritableRegularExpressionValidationRuleRequest
pub fn new( id: Uuid, ) -> PatchedBulkWritableRegularExpressionValidationRuleRequest
Serializer for RegularExpressionValidationRule objects.