PatchedBulkWritableVmInterfaceRequest

Struct PatchedBulkWritableVmInterfaceRequest 

pub struct PatchedBulkWritableVmInterfaceRequest {
Show 18 fields pub id: Uuid, pub mode: Option<InterfaceModeChoices>, pub mac_address: Option<Option<String>>, pub enabled: Option<bool>, pub mtu: Option<Option<i32>>, pub name: Option<String>, pub description: Option<String>, pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub role: Option<Option<Box<ApprovalWorkflowUser>>>, pub parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>, pub bridge: Option<Option<Box<BridgeInterface>>>, pub virtual_machine: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>, pub vrf: Option<Option<Box<ApprovalWorkflowUser>>>, pub tagged_vlans: Option<Vec<TaggedVlans>>, pub custom_fields: Option<HashMap<String, Value>>, pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}
PatchedBulkWritableVmInterfaceRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Uuidmode: Option<InterfaceModeChoices>mac_address: Option<Option<String>>enabled: Option<bool>mtu: Option<Option<i32>>name: Option<String>description: Option<String>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>role: Option<Option<Box<ApprovalWorkflowUser>>>parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>bridge: Option<Option<Box<BridgeInterface>>>virtual_machine: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>vrf: Option<Option<Box<ApprovalWorkflowUser>>>tagged_vlans: Option<Vec<TaggedVlans>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>

Implementations

Source

impl PatchedBulkWritableVmInterfaceRequest

pub fn new(id: Uuid) -> PatchedBulkWritableVmInterfaceRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.