pub struct PatchedBulkWritableVrfDeviceAssignmentRequest {
pub id: Uuid,
pub rd: Option<Option<String>>,
pub name: Option<String>,
pub vrf: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub virtual_machine: Option<Option<Box<ApprovalWorkflowUser>>>,
pub virtual_device_context: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
PatchedBulkWritableVrfDeviceAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Uuidrd: Option<Option<String>>Unique route distinguisher (as defined in RFC 4364)
name: Option<String>vrf: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>device: Option<Option<Box<ApprovalWorkflowUser>>>virtual_machine: Option<Option<Box<ApprovalWorkflowUser>>>virtual_device_context: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl PatchedBulkWritableVrfDeviceAssignmentRequest
impl PatchedBulkWritableVrfDeviceAssignmentRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableVrfDeviceAssignmentRequest
pub fn new(id: Uuid) -> PatchedBulkWritableVrfDeviceAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)