pub struct PatchedCloudNetworkPrefixAssignmentRequest {
pub id: Option<Uuid>,
pub cloud_network: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub prefix: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedCloudNetworkPrefixAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>cloud_network: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>prefix: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedCloudNetworkPrefixAssignmentRequest
impl PatchedCloudNetworkPrefixAssignmentRequest
Sourcepub fn new() -> PatchedCloudNetworkPrefixAssignmentRequest
pub fn new() -> PatchedCloudNetworkPrefixAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)