pub struct PatchedCloudServiceNetworkAssignmentRequest {
pub id: Option<Uuid>,
pub cloud_network: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub cloud_service: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedCloudServiceNetworkAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>cloud_network: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>cloud_service: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedCloudServiceNetworkAssignmentRequest
impl PatchedCloudServiceNetworkAssignmentRequest
Sourcepub fn new() -> PatchedCloudServiceNetworkAssignmentRequest
pub fn new() -> PatchedCloudServiceNetworkAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)