pub struct PatchedControllerRequest {Show 15 fields
pub id: Option<Uuid>,
pub capabilities: Option<Option<Vec<CapabilitiesEnum>>>,
pub name: Option<String>,
pub description: Option<String>,
pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub location: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub platform: Option<Option<Box<ApprovalWorkflowUser>>>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub external_integration: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller_device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub controller_device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedControllerRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>capabilities: Option<Option<Vec<CapabilitiesEnum>>>name: Option<String>description: Option<String>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>location: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>platform: Option<Option<Box<ApprovalWorkflowUser>>>role: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>external_integration: Option<Option<Box<ApprovalWorkflowUser>>>controller_device: Option<Option<Box<ApprovalWorkflowUser>>>controller_device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedControllerRequest
impl PatchedControllerRequest
Sourcepub fn new() -> PatchedControllerRequest
pub fn new() -> PatchedControllerRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.