pub struct PatchedExternalIntegrationRequest {Show 13 fields
pub id: Option<Uuid>,
pub name: Option<String>,
pub remote_url: Option<String>,
pub verify_ssl: Option<bool>,
pub timeout: Option<i32>,
pub extra_config: Option<Option<Value>>,
pub http_method: Option<Box<BulkWritableExternalIntegrationRequestHttpMethod>>,
pub headers: Option<Option<Value>>,
pub ca_file_path: Option<String>,
pub secrets_group: Option<Option<Box<BulkWritableExternalIntegrationRequestSecretsGroup>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedExternalIntegrationRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Option<String>remote_url: Option<String>verify_ssl: Option<bool>Verify SSL certificates when connecting to the remote system
timeout: Option<i32>Number of seconds to wait for a response
extra_config: Option<Option<Value>>Optional user-defined JSON data for this integration
http_method: Option<Box<BulkWritableExternalIntegrationRequestHttpMethod>>headers: Option<Option<Value>>Headers for the HTTP request
ca_file_path: Option<String>secrets_group: Option<Option<Box<BulkWritableExternalIntegrationRequestSecretsGroup>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedExternalIntegrationRequest
impl PatchedExternalIntegrationRequest
Sourcepub fn new() -> PatchedExternalIntegrationRequest
pub fn new() -> PatchedExternalIntegrationRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.