pub struct PatchedJobQueueAssignmentRequest {
pub id: Option<Uuid>,
pub job: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub job_queue: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedJobQueueAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>job: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>job_queue: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedJobQueueAssignmentRequest
impl PatchedJobQueueAssignmentRequest
Sourcepub fn new() -> PatchedJobQueueAssignmentRequest
pub fn new() -> PatchedJobQueueAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)