pub struct PatchedJobQueueRequest {
pub id: Option<Uuid>,
pub name: Option<String>,
pub description: Option<String>,
pub queue_type: Option<QueueTypeEnum>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedJobQueueRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Option<String>description: Option<String>queue_type: Option<QueueTypeEnum>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedJobQueueRequest
impl PatchedJobQueueRequest
Sourcepub fn new() -> PatchedJobQueueRequest
pub fn new() -> PatchedJobQueueRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.