PatchedModuleBayTemplateRequest

Struct PatchedModuleBayTemplateRequest 

pub struct PatchedModuleBayTemplateRequest {
    pub id: Option<Uuid>,
    pub name: Option<String>,
    pub position: Option<String>,
    pub label: Option<String>,
    pub description: Option<String>,
    pub requires_first_party_modules: Option<bool>,
    pub device_type: Option<Option<Box<ApprovalWorkflowUser>>>,
    pub module_type: Option<Option<Box<ApprovalWorkflowUser>>>,
    pub module_family: Option<Option<Box<BulkWritableModuleBayTemplateRequestModuleFamily>>>,
    pub custom_fields: Option<HashMap<String, Value>>,
    pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}
PatchedModuleBayTemplateRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>name: Option<String>position: Option<String>

The position of the module bay within the device or module

label: Option<String>

Physical label

description: Option<String>requires_first_party_modules: Option<bool>

This bay will only accept modules from the same manufacturer as the parent device or module

device_type: Option<Option<Box<ApprovalWorkflowUser>>>module_type: Option<Option<Box<ApprovalWorkflowUser>>>module_family: Option<Option<Box<BulkWritableModuleBayTemplateRequestModuleFamily>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>

Implementations

Source

impl PatchedModuleBayTemplateRequest

pub fn new() -> PatchedModuleBayTemplateRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.