pub struct PatchedNoteRequest {
pub id: Option<Uuid>,
pub assigned_object_type: Option<String>,
pub assigned_object_id: Option<Uuid>,
pub note: Option<String>,
pub user: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
PatchedNoteRequest : This base serializer implements common fields and logic for all ModelSerializers. Namely, it: - defines the display field which exposes a human friendly value for the given object. - ensures that id field is always present on the serializer as well. - ensures that created and last_updated fields are always present if applicable to this model and serializer. - ensures that object_type field is always present on the serializer which represents the content-type of this serializer’s associated model (e.g. "dcim.device"). This is required as the OpenAPI schema, using the PolymorphicProxySerializer class defined below, relies upon this field as a way to identify to the client which of several possible serializers are in use for a given attribute. - supports ?depth query parameter. It is passed in as nested_depth to the build_nested_field() function to enable the dynamic generation of nested serializers.
Fields
id: Option<Uuid>assigned_object_type: Option<String>assigned_object_id: Option<Uuid>note: Option<String>user: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl PatchedNoteRequest
impl PatchedNoteRequest
Sourcepub fn new() -> PatchedNoteRequest
pub fn new() -> PatchedNoteRequest
This base serializer implements common fields and logic for all ModelSerializers. Namely, it: - defines the display field which exposes a human friendly value for the given object. - ensures that id field is always present on the serializer as well. - ensures that created and last_updated fields are always present if applicable to this model and serializer. - ensures that object_type field is always present on the serializer which represents the content-type of this serializer’s associated model (e.g. "dcim.device"). This is required as the OpenAPI schema, using the PolymorphicProxySerializer class defined below, relies upon this field as a way to identify to the client which of several possible serializers are in use for a given attribute. - supports ?depth query parameter. It is passed in as nested_depth to the build_nested_field() function to enable the dynamic generation of nested serializers.