pub struct PatchedPrefixLocationAssignmentRequest {
pub id: Option<Uuid>,
pub prefix: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub location: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedPrefixLocationAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>prefix: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>location: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedPrefixLocationAssignmentRequest
impl PatchedPrefixLocationAssignmentRequest
Sourcepub fn new() -> PatchedPrefixLocationAssignmentRequest
pub fn new() -> PatchedPrefixLocationAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)