pub struct PatchedUserRequest {Show 13 fields
pub id: Option<Uuid>,
pub password: Option<Option<String>>,
pub last_login: Option<Option<String>>,
pub is_superuser: Option<bool>,
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub email: Option<String>,
pub is_staff: Option<bool>,
pub is_active: Option<bool>,
pub date_joined: Option<String>,
pub config_data: Option<Option<Value>>,
pub groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedUserRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>password: Option<Option<String>>last_login: Option<Option<String>>is_superuser: Option<bool>Designates that this user has all permissions without explicitly assigning them.
username: Option<String>Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.
first_name: Option<String>last_name: Option<String>email: Option<String>is_staff: Option<bool>Designates whether the user can log into this admin site.
is_active: Option<bool>Designates whether this user should be treated as active. Unselect this instead of deleting accounts.
date_joined: Option<String>config_data: Option<Option<Value>>groups: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>The groups this user belongs to. A user will get all permissions granted to each of their groups.
Implementations
Sourceimpl PatchedUserRequest
impl PatchedUserRequest
Sourcepub fn new() -> PatchedUserRequest
pub fn new() -> PatchedUserRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)