pub struct PatchedVirtualDeviceContextRequest {Show 13 fields
pub id: Option<Uuid>,
pub name: Option<String>,
pub identifier: Option<Option<i32>>,
pub description: Option<String>,
pub device: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub primary_ip4: Option<Option<Box<PrimaryIpv4>>>,
pub primary_ip6: Option<Option<Box<PrimaryIpv6>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedVirtualDeviceContextRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Option<String>identifier: Option<Option<i32>>Unique identifier provided by the platform being virtualized (Example: Nexus VDC Identifier)
description: Option<String>device: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>role: Option<Option<Box<ApprovalWorkflowUser>>>primary_ip4: Option<Option<Box<PrimaryIpv4>>>primary_ip6: Option<Option<Box<PrimaryIpv6>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedVirtualDeviceContextRequest
impl PatchedVirtualDeviceContextRequest
Sourcepub fn new() -> PatchedVirtualDeviceContextRequest
pub fn new() -> PatchedVirtualDeviceContextRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.