pub struct PatchedVirtualMachineRequest {Show 22 fields
pub id: Option<Uuid>,
pub local_config_context_data: Option<Option<Value>>,
pub local_config_context_data_owner_object_id: Option<Option<Uuid>>,
pub name: Option<String>,
pub vcpus: Option<Option<i32>>,
pub memory: Option<Option<i32>>,
pub disk: Option<Option<i32>>,
pub comments: Option<String>,
pub local_config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>,
pub local_config_context_data_owner_content_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub cluster: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub platform: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub primary_ip4: Option<Option<Box<PrimaryIpv4>>>,
pub primary_ip6: Option<Option<Box<PrimaryIpv6>>>,
pub software_version: Option<Option<Box<BulkWritableVirtualMachineRequestSoftwareVersion>>>,
pub software_image_files: Option<Vec<SoftwareImageFiles>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedVirtualMachineRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>local_config_context_data: Option<Option<Value>>local_config_context_data_owner_object_id: Option<Option<Uuid>>name: Option<String>vcpus: Option<Option<i32>>memory: Option<Option<i32>>disk: Option<Option<i32>>comments: Option<String>local_config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>local_config_context_data_owner_content_type: Option<Option<Box<ApprovalWorkflowUser>>>cluster: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>platform: Option<Option<Box<ApprovalWorkflowUser>>>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>role: Option<Option<Box<ApprovalWorkflowUser>>>primary_ip4: Option<Option<Box<PrimaryIpv4>>>primary_ip6: Option<Option<Box<PrimaryIpv6>>>software_version: Option<Option<Box<BulkWritableVirtualMachineRequestSoftwareVersion>>>software_image_files: Option<Vec<SoftwareImageFiles>>Override the software image files associated with the software version for this virtual machine
custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedVirtualMachineRequest
impl PatchedVirtualMachineRequest
Sourcepub fn new() -> PatchedVirtualMachineRequest
pub fn new() -> PatchedVirtualMachineRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.