pub struct PatchedVrfPrefixAssignmentRequest {
pub id: Option<Uuid>,
pub vrf: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub prefix: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedVrfPrefixAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>vrf: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>prefix: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>Implementations
Sourceimpl PatchedVrfPrefixAssignmentRequest
impl PatchedVrfPrefixAssignmentRequest
Sourcepub fn new() -> PatchedVrfPrefixAssignmentRequest
pub fn new() -> PatchedVrfPrefixAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)