pub struct PatchedWritableCableRequest {Show 14 fields
pub id: Option<Uuid>,
pub termination_a_type: Option<String>,
pub termination_b_type: Option<String>,
pub termination_a_id: Option<Uuid>,
pub termination_b_id: Option<Uuid>,
pub type: Option<Box<PatchedWritableCableRequestType>>,
pub label: Option<String>,
pub color: Option<String>,
pub length: Option<Option<i32>>,
pub length_unit: Option<Box<PatchedWritableCableRequestLengthUnit>>,
pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedWritableCableRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>termination_a_type: Option<String>termination_b_type: Option<String>termination_a_id: Option<Uuid>termination_b_id: Option<Uuid>type: Option<Box<PatchedWritableCableRequestType>>label: Option<String>color: Option<String>RGB color in hexadecimal (e.g. 00ff00)
length: Option<Option<i32>>length_unit: Option<Box<PatchedWritableCableRequestLengthUnit>>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedWritableCableRequest
impl PatchedWritableCableRequest
Sourcepub fn new() -> PatchedWritableCableRequest
pub fn new() -> PatchedWritableCableRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.