pub struct PatchedWritableConsoleServerPortRequest {
pub id: Option<Uuid>,
pub name: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub type: Option<Box<PatchedWritableConsolePortRequestType>>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedWritableConsoleServerPortRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Option<String>label: Option<String>Physical label
description: Option<String>type: Option<Box<PatchedWritableConsolePortRequestType>>device: Option<Option<Box<ApprovalWorkflowUser>>>module: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedWritableConsoleServerPortRequest
impl PatchedWritableConsoleServerPortRequest
Sourcepub fn new() -> PatchedWritableConsoleServerPortRequest
pub fn new() -> PatchedWritableConsoleServerPortRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.