PatchedWritableDeviceRequest

Struct PatchedWritableDeviceRequest 

pub struct PatchedWritableDeviceRequest {
Show 33 fields pub id: Option<Uuid>, pub local_config_context_data: Option<Option<Value>>, pub local_config_context_data_owner_object_id: Option<Option<Uuid>>, pub name: Option<Option<String>>, pub serial: Option<String>, pub asset_tag: Option<Option<String>>, pub position: Option<Option<i32>>, pub face: Option<Box<RackFace>>, pub device_redundancy_group_priority: Option<Option<i32>>, pub vc_position: Option<Option<i32>>, pub vc_priority: Option<Option<i32>>, pub comments: Option<String>, pub local_config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>, pub local_config_context_data_owner_content_type: Option<Option<Box<ApprovalWorkflowUser>>>, pub device_type: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub role: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>, pub platform: Option<Option<Box<ApprovalWorkflowUser>>>, pub location: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub rack: Option<Option<Box<ApprovalWorkflowUser>>>, pub primary_ip4: Option<Option<Box<PrimaryIpv4>>>, pub primary_ip6: Option<Option<Box<PrimaryIpv6>>>, pub virtual_chassis: Option<Option<Box<ApprovalWorkflowUser>>>, pub device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub software_version: Option<Option<Box<BulkWritableDeviceRequestSoftwareVersion>>>, pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub controller_managed_device_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub software_image_files: Option<Vec<SoftwareImageFiles>>, pub custom_fields: Option<HashMap<String, Value>>, pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>, pub parent_bay: Option<Option<Box<ApprovalWorkflowUser>>>,
}
PatchedWritableDeviceRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>local_config_context_data: Option<Option<Value>>local_config_context_data_owner_object_id: Option<Option<Uuid>>name: Option<Option<String>>serial: Option<String>asset_tag: Option<Option<String>>

A unique tag used to identify this device

position: Option<Option<i32>>

The lowest-numbered unit occupied by the device

face: Option<Box<RackFace>>device_redundancy_group_priority: Option<Option<i32>>

The priority the device has in the device redundancy group.

vc_position: Option<Option<i32>>vc_priority: Option<Option<i32>>comments: Option<String>local_config_context_schema: Option<Option<Box<BulkWritableConfigContextRequestConfigContextSchema>>>local_config_context_data_owner_content_type: Option<Option<Box<ApprovalWorkflowUser>>>device_type: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>role: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>platform: Option<Option<Box<ApprovalWorkflowUser>>>location: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>rack: Option<Option<Box<ApprovalWorkflowUser>>>primary_ip4: Option<Option<Box<PrimaryIpv4>>>primary_ip6: Option<Option<Box<PrimaryIpv6>>>virtual_chassis: Option<Option<Box<ApprovalWorkflowUser>>>device_redundancy_group: Option<Option<Box<ApprovalWorkflowUser>>>software_version: Option<Option<Box<BulkWritableDeviceRequestSoftwareVersion>>>secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>controller_managed_device_group: Option<Option<Box<ApprovalWorkflowUser>>>software_image_files: Option<Vec<SoftwareImageFiles>>

Override the software image files associated with the software version for this device

custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>parent_bay: Option<Option<Box<ApprovalWorkflowUser>>>

Implementations

Source

impl PatchedWritableDeviceRequest

pub fn new() -> PatchedWritableDeviceRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.