pub struct PatchedWritableInterfaceRequest {Show 26 fields
pub id: Option<Uuid>,
pub mac_address: Option<Option<String>>,
pub speed: Option<Option<i32>>,
pub name: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub enabled: Option<bool>,
pub mtu: Option<Option<i32>>,
pub mode: Option<Box<PatchedWritableInterfaceRequestMode>>,
pub type: Option<InterfaceTypeChoices>,
pub port_type: Option<Box<PatchedWritableInterfaceRequestPortType>>,
pub mgmt_only: Option<bool>,
pub duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>,
pub bridge: Option<Option<Box<BridgeInterface>>>,
pub lag: Option<Option<Box<ParentLag>>>,
pub untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vrf: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tagged_vlans: Option<Vec<TaggedVlans>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedWritableInterfaceRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>mac_address: Option<Option<String>>speed: Option<Option<i32>>name: Option<String>label: Option<String>Physical label
description: Option<String>enabled: Option<bool>mtu: Option<Option<i32>>mode: Option<Box<PatchedWritableInterfaceRequestMode>>type: Option<InterfaceTypeChoices>port_type: Option<Box<PatchedWritableInterfaceRequestPortType>>mgmt_only: Option<bool>This interface is used only for out-of-band management
duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>device: Option<Option<Box<ApprovalWorkflowUser>>>module: Option<Option<Box<ApprovalWorkflowUser>>>status: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>role: Option<Option<Box<ApprovalWorkflowUser>>>parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>bridge: Option<Option<Box<BridgeInterface>>>lag: Option<Option<Box<ParentLag>>>untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>vrf: Option<Option<Box<ApprovalWorkflowUser>>>tagged_vlans: Option<Vec<TaggedVlans>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedWritableInterfaceRequest
impl PatchedWritableInterfaceRequest
Sourcepub fn new() -> PatchedWritableInterfaceRequest
pub fn new() -> PatchedWritableInterfaceRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.