pub struct PatchedWritableInterfaceTemplateRequest {Show 13 fields
pub id: Option<Uuid>,
pub name: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub type: Option<InterfaceTypeChoices>,
pub port_type: Option<Box<PatchedWritableInterfaceRequestPortType>>,
pub mgmt_only: Option<bool>,
pub speed: Option<Option<i32>>,
pub duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>,
pub device_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedWritableInterfaceTemplateRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Option<String>label: Option<String>Physical label
description: Option<String>type: Option<InterfaceTypeChoices>port_type: Option<Box<PatchedWritableInterfaceRequestPortType>>mgmt_only: Option<bool>speed: Option<Option<i32>>duplex: Option<Box<BulkWritableInterfaceTemplateRequestDuplex>>device_type: Option<Option<Box<ApprovalWorkflowUser>>>module_type: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedWritableInterfaceTemplateRequest
impl PatchedWritableInterfaceTemplateRequest
Sourcepub fn new() -> PatchedWritableInterfaceTemplateRequest
pub fn new() -> PatchedWritableInterfaceTemplateRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.