pub struct PatchedWritableServiceRequest {
pub id: Option<Uuid>,
pub ports: Option<Vec<i32>>,
pub name: Option<String>,
pub protocol: Option<ServiceProtocolChoices>,
pub description: Option<String>,
pub device: Option<Option<Box<BulkWritableServiceRequestDevice>>>,
pub virtual_machine: Option<Option<Box<BulkWritableServiceRequestVirtualMachine>>>,
pub ip_addresses: Option<Vec<IpAddresses>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PatchedWritableServiceRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>ports: Option<Vec<i32>>name: Option<String>protocol: Option<ServiceProtocolChoices>description: Option<String>device: Option<Option<Box<BulkWritableServiceRequestDevice>>>virtual_machine: Option<Option<Box<BulkWritableServiceRequestVirtualMachine>>>ip_addresses: Option<Vec<IpAddresses>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedWritableServiceRequest
impl PatchedWritableServiceRequest
Sourcepub fn new() -> PatchedWritableServiceRequest
pub fn new() -> PatchedWritableServiceRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.