Platform

Struct Platform 

pub struct Platform {
Show 18 fields pub id: Option<Uuid>, pub object_type: Option<String>, pub display: Option<String>, pub url: Option<String>, pub natural_slug: Option<String>, pub network_driver_mappings: Option<Option<Value>>, pub device_count: Option<i32>, pub virtual_machine_count: Option<i32>, pub name: String, pub network_driver: Option<String>, pub napalm_driver: Option<String>, pub napalm_args: Option<Option<Value>>, pub description: Option<String>, pub manufacturer: Option<Option<Box<BulkWritablePlatformRequestManufacturer>>>, pub created: Option<Option<String>>, pub last_updated: Option<Option<String>>, pub notes_url: Option<String>, pub custom_fields: Option<HashMap<String, Value>>,
}
Platform : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>object_type: Option<String>display: Option<String>

Human friendly display value

url: Option<String>natural_slug: Option<String>network_driver_mappings: Option<Option<Value>>device_count: Option<i32>virtual_machine_count: Option<i32>name: Stringnetwork_driver: Option<String>

The normalized network driver to use when interacting with devices, e.g. cisco_ios, arista_eos, etc. Library-specific driver names will be derived from this setting as appropriate

napalm_driver: Option<String>

The name of the NAPALM driver to use when Nautobot internals interact with devices

napalm_args: Option<Option<Value>>

Additional arguments to pass when initiating the NAPALM driver (JSON format)

description: Option<String>manufacturer: Option<Option<Box<BulkWritablePlatformRequestManufacturer>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>

Implementations

Source

impl Platform

pub fn new(name: String) -> Platform

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.