pub struct PowerPanel {Show 17 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub panel_type: Option<Box<PowerPanelPanelType>>,
pub power_path: Option<Box<PowerFeedPowerPath>>,
pub power_feed_count: Option<i32>,
pub name: String,
pub breaker_position_count: Option<Option<i32>>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub rack_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PowerPanel : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>panel_type: Option<Box<PowerPanelPanelType>>power_path: Option<Box<PowerFeedPowerPath>>power_feed_count: Option<i32>name: Stringbreaker_position_count: Option<Option<i32>>Total number of breaker positions in the panel (e.g., 42)
location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>rack_group: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl PowerPanel
impl PowerPanel
Sourcepub fn new(
name: String,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> PowerPanel
pub fn new( name: String, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> PowerPanel
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.