pub struct PrefixLengthRequest {Show 14 fields
pub id: Option<Uuid>,
pub prefix_length: i32,
pub type: Option<PrefixTypeChoices>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub location: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vlan: Option<Option<Box<ApprovalWorkflowUser>>>,
pub rir: Option<Option<Box<BulkWritablePrefixRequestRir>>>,
pub date_allocated: Option<Option<String>>,
pub description: Option<String>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
PrefixLengthRequest : Input serializer for POST to /api/ipam/prefixes/{id}/available-prefixes/, i.e. allocating one or more sub-prefixes. Since setting of multiple locations on create is not supported, this uses the legacy single-location option.
Fields
id: Option<Uuid>prefix_length: i32type: Option<PrefixTypeChoices>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>location: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>vlan: Option<Option<Box<ApprovalWorkflowUser>>>rir: Option<Option<Box<BulkWritablePrefixRequestRir>>>date_allocated: Option<Option<String>>Date this prefix was allocated to an RIR, reserved in IPAM, etc.
description: Option<String>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PrefixLengthRequest
impl PrefixLengthRequest
Sourcepub fn new(
prefix_length: i32,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> PrefixLengthRequest
pub fn new( prefix_length: i32, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> PrefixLengthRequest
Input serializer for POST to /api/ipam/prefixes/{id}/available-prefixes/, i.e. allocating one or more sub-prefixes. Since setting of multiple locations on create is not supported, this uses the legacy single-location option.