pub struct PrefixLocationAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
PrefixLocationAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl PrefixLocationAssignment
impl PrefixLocationAssignment
Sourcepub fn new(
prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> PrefixLocationAssignment
pub fn new( prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> PrefixLocationAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)