pub struct PrefixLocationAssignmentRequest {
pub id: Option<Uuid>,
pub prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
PrefixLocationAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl PrefixLocationAssignmentRequest
impl PrefixLocationAssignmentRequest
Sourcepub fn new(
prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> PrefixLocationAssignmentRequest
pub fn new( prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> PrefixLocationAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)