pub struct Provider {Show 18 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub circuit_count: Option<i32>,
pub name: String,
pub asn: Option<Option<i64>>,
pub account: Option<String>,
pub portal_url: Option<String>,
pub noc_contact: Option<String>,
pub admin_contact: Option<String>,
pub comments: Option<String>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
Provider : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>circuit_count: Option<i32>name: Stringasn: Option<Option<i64>>32-bit autonomous system number
account: Option<String>portal_url: Option<String>noc_contact: Option<String>admin_contact: Option<String>comments: Option<String>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations