Rack

Struct Rack 

pub struct Rack {
Show 29 fields pub id: Option<Uuid>, pub object_type: Option<String>, pub display: Option<String>, pub url: Option<String>, pub natural_slug: Option<String>, pub type: Option<Box<RackType>>, pub width: Option<Box<RackWidth>>, pub outer_unit: Option<Box<RackOuterUnit>>, pub device_count: Option<i32>, pub power_feed_count: Option<i32>, pub name: String, pub facility_id: Option<Option<String>>, pub serial: Option<String>, pub asset_tag: Option<Option<String>>, pub u_height: Option<i32>, pub desc_units: Option<bool>, pub outer_width: Option<Option<i32>>, pub outer_depth: Option<Option<i32>>, pub comments: Option<String>, pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub role: Option<Option<Box<ApprovalWorkflowUser>>>, pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub rack_group: Option<Option<Box<BulkWritableRackRequestRackGroup>>>, pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>, pub created: Option<Option<String>>, pub last_updated: Option<Option<String>>, pub notes_url: Option<String>, pub custom_fields: Option<HashMap<String, Value>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}
Rack : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>object_type: Option<String>display: Option<String>

Human friendly display value

url: Option<String>natural_slug: Option<String>type: Option<Box<RackType>>width: Option<Box<RackWidth>>outer_unit: Option<Box<RackOuterUnit>>device_count: Option<i32>power_feed_count: Option<i32>name: Stringfacility_id: Option<Option<String>>

Locally-assigned identifier

serial: Option<String>asset_tag: Option<Option<String>>

A unique tag used to identify this rack

u_height: Option<i32>

Height in rack units

desc_units: Option<bool>

Units are numbered top-to-bottom

outer_width: Option<Option<i32>>

Outer dimension of rack (width)

outer_depth: Option<Option<i32>>

Outer dimension of rack (depth)

comments: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>rack_group: Option<Option<Box<BulkWritableRackRequestRackGroup>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>

Implementations

Source

impl Rack

pub fn new( name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> Rack

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.