pub struct RegularExpressionValidationRule {Show 17 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub content_type: String,
pub name: String,
pub field: String,
pub enabled: Option<bool>,
pub error_message: Option<String>,
pub regular_expression: String,
pub context_processing: Option<bool>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
RegularExpressionValidationRule : Serializer for RegularExpressionValidationRule objects.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>content_type: Stringname: Stringfield: Stringenabled: Option<bool>error_message: Option<String>Optional error message to display when validation fails.
regular_expression: Stringcontext_processing: Option<bool>When enabled, the regular expression value is first processed as a Jinja2 template with access to the context of the data being validated in a variable named object.
created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations