pub struct Service {Show 16 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub protocol: Option<Box<ServiceProtocol>>,
pub ports: Vec<i32>,
pub name: String,
pub description: Option<String>,
pub device: Option<Option<Box<BulkWritableServiceRequestDevice>>>,
pub virtual_machine: Option<Option<Box<BulkWritableServiceRequestVirtualMachine>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
Service : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>protocol: Option<Box<ServiceProtocol>>ports: Vec<i32>name: Stringdescription: Option<String>device: Option<Option<Box<BulkWritableServiceRequestDevice>>>virtual_machine: Option<Option<Box<BulkWritableServiceRequestVirtualMachine>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations