pub struct SoftwareImageFile {Show 19 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub image_file_name: String,
pub image_file_checksum: Option<String>,
pub hashing_algorithm: Option<Box<BulkWritableSoftwareImageFileRequestHashingAlgorithm>>,
pub image_file_size: Option<Option<i64>>,
pub download_url: Option<String>,
pub default_image: Option<bool>,
pub software_version: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub external_integration: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
SoftwareImageFile : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>image_file_name: Stringimage_file_checksum: Option<String>hashing_algorithm: Option<Box<BulkWritableSoftwareImageFileRequestHashingAlgorithm>>image_file_size: Option<Option<i64>>Image file size in bytes
download_url: Option<String>default_image: Option<bool>Is the default image for this software version
software_version: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>external_integration: Option<Option<Box<ApprovalWorkflowUser>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl SoftwareImageFile
impl SoftwareImageFile
Sourcepub fn new(
image_file_name: String,
software_version: ApprovalWorkflowStageResponseApprovalWorkflowStage,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> SoftwareImageFile
pub fn new( image_file_name: String, software_version: ApprovalWorkflowStageResponseApprovalWorkflowStage, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> SoftwareImageFile
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.