pub struct SoftwareVersion {Show 19 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub version: String,
pub alias: Option<String>,
pub release_date: Option<Option<String>>,
pub end_of_support_date: Option<Option<String>>,
pub documentation_url: Option<String>,
pub long_term_support: Option<bool>,
pub pre_release: Option<bool>,
pub platform: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
SoftwareVersion : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>version: Stringalias: Option<String>Optional alternative label for this version
release_date: Option<Option<String>>end_of_support_date: Option<Option<String>>documentation_url: Option<String>long_term_support: Option<bool>Is a Long Term Support version
pre_release: Option<bool>Is a Pre-Release version
platform: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl SoftwareVersion
impl SoftwareVersion
Sourcepub fn new(
version: String,
platform: ApprovalWorkflowStageResponseApprovalWorkflowStage,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> SoftwareVersion
pub fn new( version: String, platform: ApprovalWorkflowStageResponseApprovalWorkflowStage, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> SoftwareVersion
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.