Module software_version_request

Module software_version_request 

Structs

SoftwareVersionRequest
SoftwareVersionRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.