pub struct SoftwareVersionRequest {Show 13 fields
pub id: Option<Uuid>,
pub version: String,
pub alias: Option<String>,
pub release_date: Option<Option<String>>,
pub end_of_support_date: Option<Option<String>>,
pub documentation_url: Option<String>,
pub long_term_support: Option<bool>,
pub pre_release: Option<bool>,
pub platform: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
SoftwareVersionRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>version: Stringalias: Option<String>Optional alternative label for this version
release_date: Option<Option<String>>end_of_support_date: Option<Option<String>>documentation_url: Option<String>long_term_support: Option<bool>Is a Long Term Support version
pre_release: Option<bool>Is a Pre-Release version
platform: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl SoftwareVersionRequest
impl SoftwareVersionRequest
Sourcepub fn new(
version: String,
platform: ApprovalWorkflowStageResponseApprovalWorkflowStage,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> SoftwareVersionRequest
pub fn new( version: String, platform: ApprovalWorkflowStageResponseApprovalWorkflowStage, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> SoftwareVersionRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.