pub struct SupportedDataRateRequest {
pub id: Option<Uuid>,
pub standard: StandardEnum,
pub rate: i32,
pub mcs_index: Option<Option<i32>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
SupportedDataRateRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>standard: StandardEnumrate: i32mcs_index: Option<Option<i32>>The Modulation and Coding Scheme (MCS) index is a value used in wireless communications to define the modulation type, coding rate, and number of spatial streams used in a transmission.
custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl SupportedDataRateRequest
impl SupportedDataRateRequest
Sourcepub fn new(standard: StandardEnum, rate: i32) -> SupportedDataRateRequest
pub fn new(standard: StandardEnum, rate: i32) -> SupportedDataRateRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.