pub struct Vlan {Show 20 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub prefix_count: Option<i32>,
pub vid: i32,
pub name: String,
pub description: Option<String>,
pub vlan_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub computed_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
Vlan : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>prefix_count: Option<i32>vid: i32name: Stringdescription: Option<String>vlan_group: Option<Option<Box<ApprovalWorkflowUser>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>computed_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl Vlan
impl Vlan
Sourcepub fn new(
vid: i32,
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> Vlan
pub fn new( vid: i32, name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> Vlan
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.