pub struct VlanLocationAssignmentRequest {
pub id: Option<Uuid>,
pub vlan: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
VlanLocationAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>vlan: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl VlanLocationAssignmentRequest
impl VlanLocationAssignmentRequest
Sourcepub fn new(
vlan: ApprovalWorkflowStageResponseApprovalWorkflowStage,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> VlanLocationAssignmentRequest
pub fn new( vlan: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> VlanLocationAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)