pub struct VlanRequest {
pub id: Option<Uuid>,
pub location: Option<Option<Box<BulkWritablePrefixRequestLocation>>>,
pub vid: i32,
pub name: String,
pub description: Option<String>,
pub vlan_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
VlanRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>location: Option<Option<Box<BulkWritablePrefixRequestLocation>>>vid: i32name: Stringdescription: Option<String>vlan_group: Option<Option<Box<ApprovalWorkflowUser>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl VlanRequest
impl VlanRequest
Sourcepub fn new(
vid: i32,
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> VlanRequest
pub fn new( vid: i32, name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> VlanRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.