pub struct VmInterface {Show 23 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub mode: Option<Box<InterfaceMode>>,
pub mac_address: Option<Option<String>>,
pub enabled: Option<bool>,
pub mtu: Option<Option<i32>>,
pub name: String,
pub description: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>,
pub bridge: Option<Option<Box<BridgeInterface>>>,
pub virtual_machine: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>,
pub vrf: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
VmInterface : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>mode: Option<Box<InterfaceMode>>mac_address: Option<Option<String>>enabled: Option<bool>mtu: Option<Option<i32>>name: Stringdescription: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>parent_interface: Option<Option<Box<BulkWritableInterfaceRequestParentInterface>>>bridge: Option<Option<Box<BridgeInterface>>>virtual_machine: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>untagged_vlan: Option<Option<Box<ApprovalWorkflowUser>>>vrf: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl VmInterface
impl VmInterface
Sourcepub fn new(
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
virtual_machine: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> VmInterface
pub fn new( name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, virtual_machine: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> VmInterface
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.