pub struct VrfDeviceAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub rd: Option<Option<String>>,
pub name: Option<String>,
pub vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub virtual_machine: Option<Option<Box<ApprovalWorkflowUser>>>,
pub virtual_device_context: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
VrfDeviceAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>rd: Option<Option<String>>Unique route distinguisher (as defined in RFC 4364)
name: Option<String>vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>device: Option<Option<Box<ApprovalWorkflowUser>>>virtual_machine: Option<Option<Box<ApprovalWorkflowUser>>>virtual_device_context: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl VrfDeviceAssignment
impl VrfDeviceAssignment
Sourcepub fn new(
vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> VrfDeviceAssignment
pub fn new( vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> VrfDeviceAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)