pub struct VrfPrefixAssignment {
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
VrfPrefixAssignment : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl VrfPrefixAssignment
impl VrfPrefixAssignment
Sourcepub fn new(
vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage,
prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> VrfPrefixAssignment
pub fn new( vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage, prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> VrfPrefixAssignment
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)