pub struct VrfPrefixAssignmentRequest {
pub id: Option<Uuid>,
pub vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
}Expand description
VrfPrefixAssignmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>vrf: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>prefix: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>Implementations
Sourceimpl VrfPrefixAssignmentRequest
impl VrfPrefixAssignmentRequest
Sourcepub fn new(
vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage,
prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> VrfPrefixAssignmentRequest
pub fn new( vrf: ApprovalWorkflowStageResponseApprovalWorkflowStage, prefix: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> VrfPrefixAssignmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)