pub struct Webhook {Show 22 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub content_types: Vec<String>,
pub name: String,
pub type_create: Option<bool>,
pub type_update: Option<bool>,
pub type_delete: Option<bool>,
pub payload_url: String,
pub enabled: Option<bool>,
pub http_method: Option<HttpMethodEnum>,
pub http_content_type: Option<String>,
pub additional_headers: Option<String>,
pub body_template: Option<String>,
pub secret: Option<String>,
pub ssl_verification: Option<bool>,
pub ca_file_path: Option<String>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
}Expand description
Webhook : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>content_types: Vec<String>name: Stringtype_create: Option<bool>Call this webhook when a matching object is created.
type_update: Option<bool>Call this webhook when a matching object is updated.
type_delete: Option<bool>Call this webhook when a matching object is deleted.
payload_url: StringA POST will be sent to this URL when the webhook is called.
enabled: Option<bool>http_method: Option<HttpMethodEnum>http_content_type: Option<String>The complete list of official content types is available here (https://www.iana.org/assignments/media-types/media-types.xhtml).
additional_headers: Option<String>User-supplied HTTP headers to be sent with the request in addition to the HTTP content type. Headers should be defined in the format Name: Value. Jinja2 template processing is supported with the same context as the request body (below).
body_template: Option<String>Jinja2 template for a custom request body. If blank, a JSON object representing the change will be included. Available context data includes: event, model, timestamp, username, request_id, and data.
secret: Option<String>When provided, the request will include a ‘X-Hook-Signature’ header containing a HMAC hex digest of the payload body using the secret as the key. The secret is not transmitted in the request.
ssl_verification: Option<bool>Enable SSL certificate verification. Disable with caution!
ca_file_path: Option<String>The specific CA certificate file to use for SSL verification. Leave blank to use the system defaults.
created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>Implementations
Sourceimpl Webhook
impl Webhook
Sourcepub fn new(
content_types: Vec<String>,
name: String,
payload_url: String,
) -> Webhook
pub fn new( content_types: Vec<String>, name: String, payload_url: String, ) -> Webhook
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)