WirelessNetworkRequest

Struct WirelessNetworkRequest 

pub struct WirelessNetworkRequest {
Show 13 fields pub id: Option<Uuid>, pub name: String, pub description: Option<String>, pub ssid: String, pub mode: WirelessNetworkModeChoices, pub enabled: Option<bool>, pub authentication: AuthenticationEnum, pub hidden: Option<bool>, pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>, pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>, pub custom_fields: Option<HashMap<String, Value>>, pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}
WirelessNetworkRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>name: Stringdescription: Option<String>ssid: Stringmode: WirelessNetworkModeChoicesenabled: Option<bool>authentication: AuthenticationEnumhidden: Option<bool>secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>

Implementations

Source

impl WirelessNetworkRequest

pub fn new( name: String, ssid: String, mode: WirelessNetworkModeChoices, authentication: AuthenticationEnum, ) -> WirelessNetworkRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.