WritableCableRequest

Struct WritableCableRequest 

pub struct WritableCableRequest {
Show 14 fields pub id: Option<Uuid>, pub termination_a_type: String, pub termination_b_type: String, pub termination_a_id: Uuid, pub termination_b_id: Uuid, pub type: Option<Box<PatchedWritableCableRequestType>>, pub label: Option<String>, pub color: Option<String>, pub length: Option<Option<i32>>, pub length_unit: Option<Box<PatchedWritableCableRequestLengthUnit>>, pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub custom_fields: Option<HashMap<String, Value>>, pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}
WritableCableRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>termination_a_type: Stringtermination_b_type: Stringtermination_a_id: Uuidtermination_b_id: Uuidtype: Option<Box<PatchedWritableCableRequestType>>label: Option<String>color: Option<String>

RGB color in hexadecimal (e.g. 00ff00)

length: Option<Option<i32>>length_unit: Option<Box<PatchedWritableCableRequestLengthUnit>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>

Implementations

Source

impl WritableCableRequest

pub fn new( termination_a_type: String, termination_b_type: String, termination_a_id: Uuid, termination_b_id: Uuid, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> WritableCableRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.