pub struct WritableDeviceRedundancyGroupRequest {
pub id: Option<Uuid>,
pub name: String,
pub description: Option<String>,
pub failover_strategy: Option<Box<PatchedWritableDeviceRedundancyGroupRequestFailoverStrategy>>,
pub comments: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
WritableDeviceRedundancyGroupRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Stringdescription: Option<String>failover_strategy: Option<Box<PatchedWritableDeviceRedundancyGroupRequestFailoverStrategy>>comments: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>secrets_group: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl WritableDeviceRedundancyGroupRequest
impl WritableDeviceRedundancyGroupRequest
Sourcepub fn new(
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> WritableDeviceRedundancyGroupRequest
pub fn new( name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> WritableDeviceRedundancyGroupRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.