pub struct WritableFrontPortTemplateRequest {
pub id: Option<Uuid>,
pub name: String,
pub label: Option<String>,
pub description: Option<String>,
pub type: PortTypeChoices,
pub rear_port_position: Option<i32>,
pub device_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub rear_port_template: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
}Expand description
WritableFrontPortTemplateRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Stringlabel: Option<String>Physical label
description: Option<String>type: PortTypeChoicesrear_port_position: Option<i32>device_type: Option<Option<Box<ApprovalWorkflowUser>>>module_type: Option<Option<Box<ApprovalWorkflowUser>>>rear_port_template: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl WritableFrontPortTemplateRequest
impl WritableFrontPortTemplateRequest
Sourcepub fn new(
name: String,
type: PortTypeChoices,
rear_port_template: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> WritableFrontPortTemplateRequest
pub fn new( name: String, type: PortTypeChoices, rear_port_template: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> WritableFrontPortTemplateRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.