WritablePowerFeedRequest

Struct WritablePowerFeedRequest 

pub struct WritablePowerFeedRequest {
Show 20 fields pub id: Option<Uuid>, pub name: String, pub type: Option<PowerFeedTypeChoices>, pub power_path: Option<Box<PatchedWritablePowerFeedRequestPowerPath>>, pub supply: Option<SupplyEnum>, pub phase: Option<PhaseEnum>, pub voltage: Option<i32>, pub amperage: Option<i32>, pub max_utilization: Option<i32>, pub breaker_position: Option<Option<i32>>, pub breaker_pole_count: Option<Option<Box<PatchedWritablePowerFeedRequestBreakerPoleCount>>>, pub comments: Option<String>, pub cable: Option<Option<Box<ApprovalWorkflowUser>>>, pub power_panel: Box<BulkWritablePowerFeedRequestPowerPanel>, pub destination_panel: Option<Option<Box<BulkWritablePowerFeedRequestDestinationPanel>>>, pub rack: Option<Option<Box<ApprovalWorkflowUser>>>, pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>, pub custom_fields: Option<HashMap<String, Value>>, pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>, pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}
WritablePowerFeedRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.

Fields

id: Option<Uuid>name: Stringtype: Option<PowerFeedTypeChoices>power_path: Option<Box<PatchedWritablePowerFeedRequestPowerPath>>supply: Option<SupplyEnum>phase: Option<PhaseEnum>voltage: Option<i32>amperage: Option<i32>max_utilization: Option<i32>

Maximum permissible draw (percentage)

breaker_position: Option<Option<i32>>

Starting circuit breaker position in panel

breaker_pole_count: Option<Option<Box<PatchedWritablePowerFeedRequestBreakerPoleCount>>>comments: Option<String>cable: Option<Option<Box<ApprovalWorkflowUser>>>power_panel: Box<BulkWritablePowerFeedRequestPowerPanel>destination_panel: Option<Option<Box<BulkWritablePowerFeedRequestDestinationPanel>>>rack: Option<Option<Box<ApprovalWorkflowUser>>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>

Implementations

Source

impl WritablePowerFeedRequest

pub fn new( name: String, power_panel: BulkWritablePowerFeedRequestPowerPanel, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> WritablePowerFeedRequest

Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.