pub struct WritableRackRequest {Show 21 fields
pub id: Option<Uuid>,
pub name: String,
pub facility_id: Option<Option<String>>,
pub serial: Option<String>,
pub asset_tag: Option<Option<String>>,
pub type: Option<Box<PatchedWritableRackRequestType>>,
pub width: Option<i32>,
pub u_height: Option<i32>,
pub desc_units: Option<bool>,
pub outer_width: Option<Option<i32>>,
pub outer_depth: Option<Option<i32>>,
pub outer_unit: Option<Box<PatchedWritableRackRequestOuterUnit>>,
pub comments: Option<String>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub role: Option<Option<Box<ApprovalWorkflowUser>>>,
pub location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub rack_group: Option<Option<Box<BulkWritableRackRequestRackGroup>>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
WritableRackRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>name: Stringfacility_id: Option<Option<String>>Locally-assigned identifier
serial: Option<String>asset_tag: Option<Option<String>>A unique tag used to identify this rack
type: Option<Box<PatchedWritableRackRequestType>>width: Option<i32>u_height: Option<i32>Height in rack units
desc_units: Option<bool>Units are numbered top-to-bottom
outer_width: Option<Option<i32>>Outer dimension of rack (width)
outer_depth: Option<Option<i32>>Outer dimension of rack (depth)
outer_unit: Option<Box<PatchedWritableRackRequestOuterUnit>>comments: Option<String>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>role: Option<Option<Box<ApprovalWorkflowUser>>>location: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>rack_group: Option<Option<Box<BulkWritableRackRequestRackGroup>>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl WritableRackRequest
impl WritableRackRequest
Sourcepub fn new(
name: String,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
location: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> WritableRackRequest
pub fn new( name: String, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, location: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> WritableRackRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.