pub struct BulkWritableNoteRequest {
pub id: Uuid,
pub assigned_object_type: String,
pub assigned_object_id: Uuid,
pub note: String,
pub user: Option<Option<Box<ApprovalWorkflowUser>>>,
}Expand description
BulkWritableNoteRequest : This base serializer implements common fields and logic for all ModelSerializers. Namely, it: - defines the display field which exposes a human friendly value for the given object. - ensures that id field is always present on the serializer as well. - ensures that created and last_updated fields are always present if applicable to this model and serializer. - ensures that object_type field is always present on the serializer which represents the content-type of this serializer’s associated model (e.g. "dcim.device"). This is required as the OpenAPI schema, using the PolymorphicProxySerializer class defined below, relies upon this field as a way to identify to the client which of several possible serializers are in use for a given attribute. - supports ?depth query parameter. It is passed in as nested_depth to the build_nested_field() function to enable the dynamic generation of nested serializers.
Fields
id: Uuidassigned_object_type: Stringassigned_object_id: Uuidnote: Stringuser: Option<Option<Box<ApprovalWorkflowUser>>>Implementations
Sourceimpl BulkWritableNoteRequest
impl BulkWritableNoteRequest
Sourcepub fn new(
id: Uuid,
assigned_object_type: String,
assigned_object_id: Uuid,
note: String,
) -> BulkWritableNoteRequest
pub fn new( id: Uuid, assigned_object_type: String, assigned_object_id: Uuid, note: String, ) -> BulkWritableNoteRequest
This base serializer implements common fields and logic for all ModelSerializers. Namely, it: - defines the display field which exposes a human friendly value for the given object. - ensures that id field is always present on the serializer as well. - ensures that created and last_updated fields are always present if applicable to this model and serializer. - ensures that object_type field is always present on the serializer which represents the content-type of this serializer’s associated model (e.g. "dcim.device"). This is required as the OpenAPI schema, using the PolymorphicProxySerializer class defined below, relies upon this field as a way to identify to the client which of several possible serializers are in use for a given attribute. - supports ?depth query parameter. It is passed in as nested_depth to the build_nested_field() function to enable the dynamic generation of nested serializers.