pub struct Cable {Show 22 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub termination_a_type: String,
pub termination_b_type: String,
pub termination_a: Option<Box<CableTermination>>,
pub termination_b: Option<Box<CableTermination>>,
pub length_unit: Option<Box<CableLengthUnit>>,
pub type: Option<Box<CableType>>,
pub termination_a_id: Uuid,
pub termination_b_id: Uuid,
pub label: Option<String>,
pub color: Option<String>,
pub length: Option<Option<i32>>,
pub status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
Cable : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>termination_a_type: Stringtermination_b_type: Stringtermination_a: Option<Box<CableTermination>>termination_b: Option<Box<CableTermination>>length_unit: Option<Box<CableLengthUnit>>type: Option<Box<CableType>>termination_a_id: Uuidtermination_b_id: Uuidlabel: Option<String>color: Option<String>RGB color in hexadecimal (e.g. 00ff00)
length: Option<Option<i32>>status: Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl Cable
impl Cable
Sourcepub fn new(
termination_a_type: String,
termination_b_type: String,
termination_a_id: Uuid,
termination_b_id: Uuid,
status: ApprovalWorkflowStageResponseApprovalWorkflowStage,
) -> Cable
pub fn new( termination_a_type: String, termination_b_type: String, termination_a_id: Uuid, termination_b_id: Uuid, status: ApprovalWorkflowStageResponseApprovalWorkflowStage, ) -> Cable
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.