pub struct ConsolePort {Show 22 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub cable_peer_type: Option<Option<String>>,
pub cable_peer: Option<Option<Box<CableTermination>>>,
pub connected_endpoint_type: Option<Option<String>>,
pub connected_endpoint: Option<Option<Box<PathEndpoint>>>,
pub connected_endpoint_reachable: Option<Option<bool>>,
pub type: Option<Box<ConsolePortType>>,
pub name: String,
pub label: Option<String>,
pub description: Option<String>,
pub device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub cable: Option<Option<Box<CircuitCircuitTerminationA>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
ConsolePort : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>cable_peer_type: Option<Option<String>>cable_peer: Option<Option<Box<CableTermination>>>connected_endpoint_type: Option<Option<String>>connected_endpoint: Option<Option<Box<PathEndpoint>>>connected_endpoint_reachable: Option<Option<bool>>type: Option<Box<ConsolePortType>>name: Stringlabel: Option<String>Physical label
description: Option<String>device: Option<Option<Box<ApprovalWorkflowUser>>>module: Option<Option<Box<ApprovalWorkflowUser>>>cable: Option<Option<Box<CircuitCircuitTerminationA>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl ConsolePort
impl ConsolePort
Sourcepub fn new(name: String) -> ConsolePort
pub fn new(name: String) -> ConsolePort
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.