pub struct ModuleBayTemplate {Show 17 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub notes_url: Option<String>,
pub name: String,
pub position: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub requires_first_party_modules: Option<bool>,
pub device_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_type: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_family: Option<Option<Box<BulkWritableModuleBayTemplateRequestModuleFamily>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
ModuleBayTemplate : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>notes_url: Option<String>name: Stringposition: Option<String>The position of the module bay within the device or module
label: Option<String>Physical label
description: Option<String>requires_first_party_modules: Option<bool>This bay will only accept modules from the same manufacturer as the parent device or module
device_type: Option<Option<Box<ApprovalWorkflowUser>>>module_type: Option<Option<Box<ApprovalWorkflowUser>>>module_family: Option<Option<Box<BulkWritableModuleBayTemplateRequestModuleFamily>>>created: Option<Option<String>>last_updated: Option<Option<String>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl ModuleBayTemplate
impl ModuleBayTemplate
Sourcepub fn new(name: String) -> ModuleBayTemplate
pub fn new(name: String) -> ModuleBayTemplate
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.