pub struct PatchedBulkWritableModuleBayRequest {
pub id: Uuid,
pub requires_first_party_modules: Option<bool>,
pub name: Option<String>,
pub position: Option<String>,
pub label: Option<String>,
pub description: Option<String>,
pub parent_device: Option<Option<Box<ApprovalWorkflowUser>>>,
pub parent_module: Option<Option<Box<ApprovalWorkflowUser>>>,
pub module_family: Option<Option<Box<BulkWritableModuleBayRequestModuleFamily>>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
}Expand description
PatchedBulkWritableModuleBayRequest : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Uuidrequires_first_party_modules: Option<bool>This bay will only accept modules from the same manufacturer as the parent device or module
name: Option<String>position: Option<String>The position of the module bay within the parent device/module
label: Option<String>Physical label
description: Option<String>parent_device: Option<Option<Box<ApprovalWorkflowUser>>>parent_module: Option<Option<Box<ApprovalWorkflowUser>>>module_family: Option<Option<Box<BulkWritableModuleBayRequestModuleFamily>>>custom_fields: Option<HashMap<String, Value>>relationships: Option<HashMap<String, ApprovalWorkflowDefinitionRequestRelationshipsValue>>Implementations
Sourceimpl PatchedBulkWritableModuleBayRequest
impl PatchedBulkWritableModuleBayRequest
Sourcepub fn new(id: Uuid) -> PatchedBulkWritableModuleBayRequest
pub fn new(id: Uuid) -> PatchedBulkWritableModuleBayRequest
Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.