pub struct Vrf {Show 16 fields
pub id: Option<Uuid>,
pub object_type: Option<String>,
pub display: Option<String>,
pub url: Option<String>,
pub natural_slug: Option<String>,
pub name: String,
pub rd: Option<Option<String>>,
pub description: Option<String>,
pub status: Option<Option<Box<ApprovalWorkflowUser>>>,
pub namespace: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub tenant: Option<Option<Box<ApprovalWorkflowUser>>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub tags: Option<Vec<ApprovalWorkflowStageResponseApprovalWorkflowStage>>,
pub notes_url: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
Vrf : Base class to use for serializers based on OrganizationalModel or PrimaryModel. Can also be used for models derived from BaseModel, so long as they support custom fields, notes, and relationships.
Fields
id: Option<Uuid>object_type: Option<String>display: Option<String>Human friendly display value
url: Option<String>natural_slug: Option<String>name: Stringrd: Option<Option<String>>Unique route distinguisher (as defined in RFC 4364)
description: Option<String>status: Option<Option<Box<ApprovalWorkflowUser>>>namespace: Option<Box<ApprovalWorkflowStageResponseApprovalWorkflowStage>>tenant: Option<Option<Box<ApprovalWorkflowUser>>>created: Option<Option<String>>last_updated: Option<Option<String>>notes_url: Option<String>custom_fields: Option<HashMap<String, Value>>Implementations